Class: Aws::GameLift::Types::ContainerPortMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Describes a mapping between a container port and a connection port on a fleet instance. You define container ports in a container group definition. Amazon GameLift Servers assigns connection ports when it deploys the container group to an instance.

**Part of:** [ContainerGroupPortMapping]

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_ContainerGroupPortMapping.html

Constant Summary collapse

SENSITIVE =
[:container_port, :connection_port]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_portInteger

The port number on the fleet instance that maps to the container port. Connection ports are assigned by Amazon GameLift Servers when the container group is deployed to an instance.

Returns:

  • (Integer)


1411
1412
1413
1414
1415
1416
1417
# File 'lib/aws-sdk-gamelift/types.rb', line 1411

class ContainerPortMapping < Struct.new(
  :container_port,
  :connection_port,
  :protocol)
  SENSITIVE = [:container_port, :connection_port]
  include Aws::Structure
end

#container_portInteger

The port number on the container. This port is defined in the container group definition. Container port numbers must be unique within a container group definition.

Returns:

  • (Integer)


1411
1412
1413
1414
1415
1416
1417
# File 'lib/aws-sdk-gamelift/types.rb', line 1411

class ContainerPortMapping < Struct.new(
  :container_port,
  :connection_port,
  :protocol)
  SENSITIVE = [:container_port, :connection_port]
  include Aws::Structure
end

#protocolString

The network protocol for the port mapping. Valid values are ‘TCP` or `UDP`.

Returns:

  • (String)


1411
1412
1413
1414
1415
1416
1417
# File 'lib/aws-sdk-gamelift/types.rb', line 1411

class ContainerPortMapping < Struct.new(
  :container_port,
  :connection_port,
  :protocol)
  SENSITIVE = [:container_port, :connection_port]
  include Aws::Structure
end