Class: Aws::GameLift::Types::CreateContainerGroupDefinitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::CreateContainerGroupDefinitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_group_type ⇒ String
The type of container group being defined.
-
#game_server_container_definition ⇒ Types::GameServerContainerDefinitionInput
The definition for the game server container in this group.
-
#name ⇒ String
A descriptive identifier for the container group definition.
-
#operating_system ⇒ String
The platform that all containers in the group use.
-
#support_container_definitions ⇒ Array<Types::SupportContainerDefinitionInput>
One or more definition for support containers in this group.
-
#tags ⇒ Array<Types::Tag>
A list of labels to assign to the container group definition resource.
-
#total_memory_limit_mebibytes ⇒ Integer
The maximum amount of memory (in MiB) to allocate to the container group.
-
#total_vcpu_limit ⇒ Float
The maximum amount of vCPU units to allocate to the container group (1 vCPU is equal to 1024 CPU units).
-
#version_description ⇒ String
A description for the initial version of this container group definition.
Instance Attribute Details
#container_group_type ⇒ String
The type of container group being defined. Container group type determines how Amazon GameLift Servers deploys the container group on each fleet instance.
Default value: GAME_SERVER
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#game_server_container_definition ⇒ Types::GameServerContainerDefinitionInput
The definition for the game server container in this group. Define a game server container only when the container group type is GAME_SERVER. Game server containers specify a container image with your game server build. You can pass in your container definitions as a JSON file.
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive identifier for the container group definition. The name value must be unique in an Amazon Web Services Region.
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#operating_system ⇒ String
The platform that all containers in the group use. Containers in a group must run on the same operating system.
Default value: AMAZON_LINUX_2023
<note markdown=“1”> Amazon Linux 2 (AL2) will reach end of support on 6/30/2026. See more details in the [Amazon Linux 2 FAQs]. For game servers that are hosted on AL2 and use server SDK version 4.x for Amazon GameLift Servers, first update the game server build to server SDK 5.x, and then deploy to AL2023 instances. See [ Migrate to server SDK version 5.]
</note>
[1]: aws.amazon.com/amazon-linux-2/faqs/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/reference-serversdk5-migration.html
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#support_container_definitions ⇒ Array<Types::SupportContainerDefinitionInput>
One or more definition for support containers in this group. You can define a support container in any type of container group. You can pass in your container definitions as a JSON file.
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of labels to assign to the container group definition resource. Tags are developer-defined key-value pairs. Tagging Amazon Web Services resources are useful for resource management, access management and cost allocation. For more information, see [ Tagging Amazon Web Services Resources] in the *Amazon Web Services General Reference*.
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#total_memory_limit_mebibytes ⇒ Integer
The maximum amount of memory (in MiB) to allocate to the container group. All containers in the group share this memory. If you specify memory limits for an individual container, the total value must be greater than any individual container’s memory limit.
Default value: 1024
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#total_vcpu_limit ⇒ Float
The maximum amount of vCPU units to allocate to the container group (1 vCPU is equal to 1024 CPU units). All containers in the group share this memory. If you specify vCPU limits for individual containers, the total value must be equal to or greater than the sum of the CPU limits for all containers in the group.
Default value: 1
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |
#version_description ⇒ String
A description for the initial version of this container group definition.
1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-gamelift/types.rb', line 1961 class CreateContainerGroupDefinitionInput < Struct.new( :name, :container_group_type, :total_memory_limit_mebibytes, :total_vcpu_limit, :game_server_container_definition, :support_container_definitions, :operating_system, :version_description, :tags) SENSITIVE = [] include Aws::Structure end |