Class: Aws::GameLift::Types::CreateGameServerGroupOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_server_groupTypes::GameServerGroup

The newly created game server group object, including the new ARN value for the Amazon GameLift Servers FleetIQ game server group and the object’s status. The Amazon EC2 Auto Scaling group ARN is initially null, since the group has not yet been created. This value is added once the game server group status reaches ACTIVE.

Returns:



2577
2578
2579
2580
2581
# File 'lib/aws-sdk-gamelift/types.rb', line 2577

class CreateGameServerGroupOutput < Struct.new(
  :game_server_group)
  SENSITIVE = []
  include Aws::Structure
end