Class: Aws::GameLift::Types::CreatePlayerSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::CreatePlayerSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:player_id]
Instance Attribute Summary collapse
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to add a player to.
-
#player_data ⇒ String
Developer-defined information related to a player.
-
#player_id ⇒ String
A unique identifier for a player.
Instance Attribute Details
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to add a player to. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3201 class CreatePlayerSessionInput < Struct.new( :game_session_id, :player_id, :player_data) SENSITIVE = [:player_id] include Aws::Structure end |
#player_data ⇒ String
Developer-defined information related to a player. Amazon GameLift Servers does not use this data, so it can be formatted as needed for use in the game.
3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3201 class CreatePlayerSessionInput < Struct.new( :game_session_id, :player_id, :player_data) SENSITIVE = [:player_id] include Aws::Structure end |
#player_id ⇒ String
A unique identifier for a player. Player IDs are developer-defined.
3201 3202 3203 3204 3205 3206 3207 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3201 class CreatePlayerSessionInput < Struct.new( :game_session_id, :player_id, :player_data) SENSITIVE = [:player_id] include Aws::Structure end |