Class: Aws::GameLift::Types::CreatePlayerSessionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:player_ids]

Instance Attribute Summary collapse

Instance Attribute Details

#game_session_idString

An identifier for the game session that is unique across all regions to add players to. The value is always a full ARN in the following format: For Home Region game session - ‘arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<ID string>`. For Remote Location game session - `arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<location>/<ID string>`.

Returns:

  • (String)


3250
3251
3252
3253
3254
3255
3256
# File 'lib/aws-sdk-gamelift/types.rb', line 3250

class CreatePlayerSessionsInput < Struct.new(
  :game_session_id,
  :player_ids,
  :player_data_map)
  SENSITIVE = [:player_ids]
  include Aws::Structure
end

#player_data_mapHash<String,String>

Map of string pairs, each specifying a player ID and a set of developer-defined information related to the player. Amazon GameLift Servers does not use this data, so it can be formatted as needed for use in the game. Any player data strings for player IDs that are not included in the ‘PlayerIds` parameter are ignored.

Returns:

  • (Hash<String,String>)


3250
3251
3252
3253
3254
3255
3256
# File 'lib/aws-sdk-gamelift/types.rb', line 3250

class CreatePlayerSessionsInput < Struct.new(
  :game_session_id,
  :player_ids,
  :player_data_map)
  SENSITIVE = [:player_ids]
  include Aws::Structure
end

#player_idsArray<String>

List of unique identifiers for the players to be added.

Returns:

  • (Array<String>)


3250
3251
3252
3253
3254
3255
3256
# File 'lib/aws-sdk-gamelift/types.rb', line 3250

class CreatePlayerSessionsInput < Struct.new(
  :game_session_id,
  :player_ids,
  :player_data_map)
  SENSITIVE = [:player_ids]
  include Aws::Structure
end