Class: Aws::GameLift::Types::CreateVpcPeeringAuthorizationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::CreateVpcPeeringAuthorizationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_lift_aws_account_id ⇒ String
A unique identifier for the Amazon Web Services account that you use to manage your Amazon GameLift Servers fleet.
-
#peer_vpc_id ⇒ String
A unique identifier for a VPC with resources to be accessed by your Amazon GameLift Servers fleet.
Instance Attribute Details
#game_lift_aws_account_id ⇒ String
A unique identifier for the Amazon Web Services account that you use to manage your Amazon GameLift Servers fleet. You can find your Account ID in the Amazon Web Services Management Console under account settings.
3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3410 class CreateVpcPeeringAuthorizationInput < Struct.new( :game_lift_aws_account_id, :peer_vpc_id) SENSITIVE = [] include Aws::Structure end |
#peer_vpc_id ⇒ String
A unique identifier for a VPC with resources to be accessed by your Amazon GameLift Servers fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the Amazon Web Services Management Console. Learn more about VPC peering in VPC Peering with Amazon GameLift Servers Fleets.
3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3410 class CreateVpcPeeringAuthorizationInput < Struct.new( :game_lift_aws_account_id, :peer_vpc_id) SENSITIVE = [] include Aws::Structure end |