Class: Aws::GameLift::Types::DeleteGameSessionQueueInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DeleteGameSessionQueueInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
A descriptive label that is associated with game session queue.
Instance Attribute Details
#name ⇒ String
A descriptive label that is associated with game session queue. Queue names must be unique within each Region. You can use either the queue ID or ARN value.
3534 3535 3536 3537 3538 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3534 class DeleteGameSessionQueueInput < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |