Class: Aws::GameLift::Types::DescribeContainerGroupPortMappingsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_nameString

A unique identifier for the compute resource for which to retrieve port mappings. For a container fleet, a compute represents a game server container group running on a fleet instance. You can use either the compute name or ARN value.

When ‘ContainerGroupType` is `GAME_SERVER`, this parameter is required.

When ‘ContainerGroupType` is `PER_INSTANCE`, do not provide this parameter. If you provide a compute name with `PER_INSTANCE`, the request fails with an `InvalidRequestException`.

Returns:

  • (String)


4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-gamelift/types.rb', line 4087

class DescribeContainerGroupPortMappingsInput < Struct.new(
  :fleet_id,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_name)
  SENSITIVE = []
  include Aws::Structure
end

#container_group_typeString

The type of container group to retrieve port mappings for.

  • ‘GAME_SERVER` – Get port mappings for a game server container group.

  • ‘PER_INSTANCE` – Get port mappings for a per-instance container group.

Returns:

  • (String)


4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-gamelift/types.rb', line 4087

class DescribeContainerGroupPortMappingsInput < Struct.new(
  :fleet_id,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_name)
  SENSITIVE = []
  include Aws::Structure
end

#container_nameString

A container name to filter the results. When provided, the operation returns port mappings for the specified container only. If no container with the specified name exists in the container group, the request fails with a ‘NotFoundException`.

If not provided, the operation returns port mappings for all containers in the container group.

Returns:

  • (String)


4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-gamelift/types.rb', line 4087

class DescribeContainerGroupPortMappingsInput < Struct.new(
  :fleet_id,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_name)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the container fleet. You can use either the fleet ID or ARN value.

Returns:

  • (String)


4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-gamelift/types.rb', line 4087

class DescribeContainerGroupPortMappingsInput < Struct.new(
  :fleet_id,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_name)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

A unique identifier for the fleet instance to retrieve port mappings for.

When ‘ContainerGroupType` is `PER_INSTANCE`, this parameter is required.

When ‘ContainerGroupType` is `GAME_SERVER`, this parameter is optional. If you provide an instance ID, it must match the instance that’s running the specified compute. If the instance ID doesn’t match, the request fails with an ‘InvalidRequestException`.

Returns:

  • (String)


4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/aws-sdk-gamelift/types.rb', line 4087

class DescribeContainerGroupPortMappingsInput < Struct.new(
  :fleet_id,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_name)
  SENSITIVE = []
  include Aws::Structure
end