Class: Aws::GameLift::Types::DescribeContainerGroupPortMappingsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_nameString

A unique identifier for the compute resource running the game server container group. Returned when ContainerGroupType is GAME_SERVER.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#container_group_definition_arnString

The Amazon Resource Name (ARN) that is assigned to the container group definition. The ARN value also identifies the specific container group definition version in use.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#container_group_port_mappingsArray<Types::ContainerGroupPortMapping>

A list of ContainerGroupPortMapping objects that describe the port mappings for each container in the container group.



4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#container_group_typeString

The type of container group that was specified in the request. Valid values are GAME_SERVER or PER_INSTANCE.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_arnString

The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912. In a GameLift fleet ARN, the resource ID matches the FleetId value.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the container fleet.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#instance_idString

A unique identifier for the fleet instance. For GAME_SERVER requests, this is the instance running the specified compute. For PER_INSTANCE requests, this is the instance specified in the request.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The location of the fleet instance, expressed as an Amazon Web Services Region code, such as us-west-2.

Returns:

  • (String)


4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/aws-sdk-gamelift/types.rb', line 4154

class DescribeContainerGroupPortMappingsOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location,
  :container_group_definition_arn,
  :container_group_type,
  :compute_name,
  :instance_id,
  :container_group_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end