Class: Aws::GameLift::Types::DescribeFleetAttributesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_attributesArray<Types::FleetAttributes>

A collection of objects containing attribute metadata for each requested fleet ID. Attribute objects are returned only for fleets that currently exist.



3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-gamelift/types.rb', line 3998

class DescribeFleetAttributesOutput < Struct.new(
  :fleet_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



3998
3999
4000
4001
4002
4003
# File 'lib/aws-sdk-gamelift/types.rb', line 3998

class DescribeFleetAttributesOutput < Struct.new(
  :fleet_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end