Class: Aws::GameLift::Types::DescribeFleetCapacityOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetCapacityOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_capacity ⇒ Array<Types::FleetCapacity>
A collection of objects that contains capacity information for each requested fleet ID.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#fleet_capacity ⇒ Array<Types::FleetCapacity>
A collection of objects that contains capacity information for each requested fleet ID. Capacity objects are returned only for fleets that currently exist. Changes in desired instance value can take up to 1 minute to be reflected.
4051 4052 4053 4054 4055 4056 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4051 class DescribeFleetCapacityOutput < Struct.new( :fleet_capacity, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4051 4052 4053 4054 4055 4056 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4051 class DescribeFleetCapacityOutput < Struct.new( :fleet_capacity, :next_token) SENSITIVE = [] include Aws::Structure end |