Class: Aws::GameLift::Types::DescribeFleetEventsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:events]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::Event>

A collection of objects containing event log entries for the specified fleet.



4404
4405
4406
4407
4408
4409
# File 'lib/aws-sdk-gamelift/types.rb', line 4404

class DescribeFleetEventsOutput < Struct.new(
  :events,
  :next_token)
  SENSITIVE = [:events]
  include Aws::Structure
end

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



4404
4405
4406
4407
4408
4409
# File 'lib/aws-sdk-gamelift/types.rb', line 4404

class DescribeFleetEventsOutput < Struct.new(
  :events,
  :next_token)
  SENSITIVE = [:events]
  include Aws::Structure
end