Class: Aws::GameLift::Types::DescribeFleetLocationAttributesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_arnString

The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912.



4475
4476
4477
4478
4479
4480
4481
4482
# File 'lib/aws-sdk-gamelift/types.rb', line 4475

class DescribeFleetLocationAttributesOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the fleet that location attributes were requested for.



4475
4476
4477
4478
4479
4480
4481
4482
# File 'lib/aws-sdk-gamelift/types.rb', line 4475

class DescribeFleetLocationAttributesOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#location_attributesArray<Types::LocationAttributes>

Location-specific information on the requested fleet's remote locations.



4475
4476
4477
4478
4479
4480
4481
4482
# File 'lib/aws-sdk-gamelift/types.rb', line 4475

class DescribeFleetLocationAttributesOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



4475
4476
4477
4478
4479
4480
4481
4482
# File 'lib/aws-sdk-gamelift/types.rb', line 4475

class DescribeFleetLocationAttributesOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :location_attributes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end