Class: Aws::GameLift::Types::DescribeFleetPortSettingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetPortSettingsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN][1]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it.
-
#fleet_id ⇒ String
A unique identifier for the fleet that was requested.
-
#inbound_permissions ⇒ Array<Types::IpPermission>
The port settings for the requested fleet ID.
-
#location ⇒ String
The requested fleet location, expressed as an Amazon Web Services Region code, such as
us-west-2. -
#update_status ⇒ String
The current status of updates to the fleet's port settings in the requested fleet location.
Instance Attribute Details
#fleet_arn ⇒ String
The Amazon Resource Name (ARN) that is assigned to a Amazon
GameLift Servers fleet resource and uniquely identifies it. ARNs are
unique across all Regions. Format is
arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912.
4599 4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4599 class DescribeFleetPortSettingsOutput < Struct.new( :fleet_id, :fleet_arn, :inbound_permissions, :update_status, :location) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that was requested.
4599 4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4599 class DescribeFleetPortSettingsOutput < Struct.new( :fleet_id, :fleet_arn, :inbound_permissions, :update_status, :location) SENSITIVE = [] include Aws::Structure end |
#inbound_permissions ⇒ Array<Types::IpPermission>
The port settings for the requested fleet ID.
4599 4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4599 class DescribeFleetPortSettingsOutput < Struct.new( :fleet_id, :fleet_arn, :inbound_permissions, :update_status, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The requested fleet location, expressed as an Amazon Web Services
Region code, such as us-west-2.
4599 4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4599 class DescribeFleetPortSettingsOutput < Struct.new( :fleet_id, :fleet_arn, :inbound_permissions, :update_status, :location) SENSITIVE = [] include Aws::Structure end |
#update_status ⇒ String
The current status of updates to the fleet's port settings in the
requested fleet location. A status of PENDING_UPDATE indicates
that an update was requested for the fleet but has not yet been
completed for the location.
4599 4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4599 class DescribeFleetPortSettingsOutput < Struct.new( :fleet_id, :fleet_arn, :inbound_permissions, :update_status, :location) SENSITIVE = [] include Aws::Structure end |