Class: Aws::GameLift::Types::DescribeFleetUtilizationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_idsArray<String>

A unique identifier for the fleet to retrieve utilization data for. You can use either the fleet ID or ARN value. To retrieve attributes for all current fleets, do not include this parameter.

Returns:

  • (Array<String>)


4384
4385
4386
4387
4388
4389
4390
# File 'lib/aws-sdk-gamelift/types.rb', line 4384

class DescribeFleetUtilizationInput < Struct.new(
  :fleet_ids,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs.

Returns:

  • (Integer)


4384
4385
4386
4387
4388
4389
4390
# File 'lib/aws-sdk-gamelift/types.rb', line 4384

class DescribeFleetUtilizationInput < Struct.new(
  :fleet_ids,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs.

Returns:

  • (String)


4384
4385
4386
4387
4388
4389
4390
# File 'lib/aws-sdk-gamelift/types.rb', line 4384

class DescribeFleetUtilizationInput < Struct.new(
  :fleet_ids,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end