Class: Aws::GameLift::Types::DescribeFleetUtilizationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_utilizationArray<Types::FleetUtilization>

A collection of objects containing utilization information for each requested fleet ID. Utilization objects are returned only for fleets that currently exist.



4277
4278
4279
4280
4281
4282
# File 'lib/aws-sdk-gamelift/types.rb', line 4277

class DescribeFleetUtilizationOutput < Struct.new(
  :fleet_utilization,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



4277
4278
4279
4280
4281
4282
# File 'lib/aws-sdk-gamelift/types.rb', line 4277

class DescribeFleetUtilizationOutput < Struct.new(
  :fleet_utilization,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end