Class: Aws::GameLift::Types::DescribeGameSessionDetailsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameSessionDetailsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_id ⇒ String
A unique identifier for the alias associated with the fleet to retrieve all game sessions for.
-
#fleet_id ⇒ String
A unique identifier for the fleet to retrieve all game sessions active on the fleet.
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to retrieve.
-
#limit ⇒ Integer
The maximum number of results to return.
-
#location ⇒ String
A fleet location to get game session details for.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
-
#status_filter ⇒ String
Game session status to filter results on.
Instance Attribute Details
#alias_id ⇒ String
A unique identifier for the alias associated with the fleet to retrieve all game sessions for. You can use either the alias ID or ARN value.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet to retrieve all game sessions active on the fleet. You can use either the fleet ID or ARN value.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to retrieve. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with ‘NextToken` to get results as a set of sequential pages.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
A fleet location to get game session details for. You can specify a fleet’s home Region or a remote location. Use the Amazon Web Services Region code format, such as ‘us-west-2`.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#status_filter ⇒ String
Game session status to filter results on. Possible game session statuses include ‘ACTIVE`, `TERMINATED`, `ACTIVATING` and `TERMINATING` (the last two are transitory).
4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4793 class DescribeGameSessionDetailsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |