Class: Aws::GameLift::Types::DescribeGameSessionDetailsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameSessionDetailsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session_details ⇒ Array<Types::GameSessionDetail>
A collection of properties for each game session that matches the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_session_details ⇒ Array<Types::GameSessionDetail>
A collection of properties for each game session that matches the request.
4590 4591 4592 4593 4594 4595 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4590 class DescribeGameSessionDetailsOutput < Struct.new( :game_session_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4590 4591 4592 4593 4594 4595 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4590 class DescribeGameSessionDetailsOutput < Struct.new( :game_session_details, :next_token) SENSITIVE = [] include Aws::Structure end |