Class: Aws::GameLift::Types::DescribeGameSessionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameSessionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_id ⇒ String
A unique identifier for the alias associated with the fleet to retrieve game sessions for.
-
#fleet_id ⇒ String
A unique identifier for the fleet to retrieve game sessions for.
-
#game_session_id ⇒ String
A unique identifier for the game session to retrieve.
-
#limit ⇒ Integer
The maximum number of results to return.
-
#location ⇒ String
A fleet location to get game sessions for.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
-
#status_filter ⇒ String
Game session status to filter results on.
Instance Attribute Details
#alias_id ⇒ String
A unique identifier for the alias associated with the fleet to retrieve game sessions for. You can use either the alias ID or ARN value.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet to retrieve game sessions for. You can use either the fleet ID or ARN value.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#game_session_id ⇒ String
A unique identifier for the game session to retrieve.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
A fleet location to get game sessions for. You can specify a fleet’s home Region or a remote location. Use the Amazon Web Services Region code format, such as us-west-2.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#status_filter ⇒ String
Game session status to filter results on. You can filter on the following states: ACTIVE, TERMINATED, ACTIVATING, and TERMINATING. The last two are transitory and used for only very brief periods of time.
4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4712 class DescribeGameSessionsInput < Struct.new( :fleet_id, :game_session_id, :alias_id, :location, :status_filter, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |