Class: Aws::GameLift::Types::DescribeGameSessionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameSessionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_sessions ⇒ Array<Types::GameSession>
A collection of properties for each game session that matches the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_sessions ⇒ Array<Types::GameSession>
A collection of properties for each game session that matches the request.
5003 5004 5005 5006 5007 5008 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5003 class DescribeGameSessionsOutput < Struct.new( :game_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5003 5004 5005 5006 5007 5008 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5003 class DescribeGameSessionsOutput < Struct.new( :game_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |