Class: Aws::GameLift::Types::DescribeInstancesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeInstancesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::Instance>
A collection of objects containing properties for each instance returned.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#instances ⇒ Array<Types::Instance>
A collection of objects containing properties for each instance returned.
4796 4797 4798 4799 4800 4801 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4796 class DescribeInstancesOutput < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4796 4797 4798 4799 4800 4801 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4796 class DescribeInstancesOutput < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |