Class: Aws::GameLift::Types::DescribeMatchmakingConfigurationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeMatchmakingConfigurationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of results to return.
-
#names ⇒ Array<String>
A unique identifier for the matchmaking configuration(s) to retrieve.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
-
#rule_set_name ⇒ String
A unique identifier for the matchmaking rule set.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with ‘NextToken` to get results as a set of sequential pages. This parameter is limited to 10.
5090 5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5090 class DescribeMatchmakingConfigurationsInput < Struct.new( :names, :rule_set_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#names ⇒ Array<String>
A unique identifier for the matchmaking configuration(s) to retrieve. You can use either the configuration name or ARN value. To request all existing configurations, leave this parameter empty.
5090 5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5090 class DescribeMatchmakingConfigurationsInput < Struct.new( :names, :rule_set_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
5090 5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5090 class DescribeMatchmakingConfigurationsInput < Struct.new( :names, :rule_set_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#rule_set_name ⇒ String
A unique identifier for the matchmaking rule set. You can use either the rule set name or ARN value. Use this parameter to retrieve all matchmaking configurations that use this rule set.
5090 5091 5092 5093 5094 5095 5096 5097 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5090 class DescribeMatchmakingConfigurationsInput < Struct.new( :names, :rule_set_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |