Class: Aws::GameLift::Types::DescribeMatchmakingRuleSetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeMatchmakingRuleSetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of results to return.
-
#names ⇒ Array<String>
A list of one or more matchmaking rule set names to retrieve details for.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with ‘NextToken` to get results as a set of sequential pages.
5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5165 class DescribeMatchmakingRuleSetsInput < Struct.new( :names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#names ⇒ Array<String>
A list of one or more matchmaking rule set names to retrieve details for. (Note: The rule set name is different from the optional “name” field in the rule set body.) You can use either the rule set name or ARN value.
5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5165 class DescribeMatchmakingRuleSetsInput < Struct.new( :names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5165 class DescribeMatchmakingRuleSetsInput < Struct.new( :names, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |