Class: Aws::GameLift::Types::DescribeMatchmakingRuleSetsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



5191
5192
5193
5194
5195
5196
# File 'lib/aws-sdk-gamelift/types.rb', line 5191

class DescribeMatchmakingRuleSetsOutput < Struct.new(
  :rule_sets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_setsArray<Types::MatchmakingRuleSet>

A collection of requested matchmaking rule set objects.



5191
5192
5193
5194
5195
5196
# File 'lib/aws-sdk-gamelift/types.rb', line 5191

class DescribeMatchmakingRuleSetsOutput < Struct.new(
  :rule_sets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end