Class: Aws::GameLift::Types::DescribePlayerSessionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribePlayerSessionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
-
#player_sessions ⇒ Array<Types::PlayerSession>
A collection of objects containing properties for each player session that matches the request.
Instance Attribute Details
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5007 5008 5009 5010 5011 5012 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5007 class DescribePlayerSessionsOutput < Struct.new( :player_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#player_sessions ⇒ Array<Types::PlayerSession>
A collection of objects containing properties for each player session that matches the request.
5007 5008 5009 5010 5011 5012 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5007 class DescribePlayerSessionsOutput < Struct.new( :player_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |