Class: Aws::GameLift::Types::EC2InstanceLimit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

The Amazon GameLift Servers service limits for an Amazon EC2 instance type and current utilization. Amazon GameLift Servers allows Amazon Web Services accounts a maximum number of instances, per instance type, per Amazon Web Services Region or location, for use with Amazon GameLift Servers. You can request an limit increase for your account by using the **Service limits** page in the Amazon GameLift Servers console.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_instancesInteger

The number of instances for the specified type and location that are currently being used by the Amazon Web Services account.

Returns:

  • (Integer)


5295
5296
5297
5298
5299
5300
5301
5302
# File 'lib/aws-sdk-gamelift/types.rb', line 5295

class EC2InstanceLimit < Struct.new(
  :ec2_instance_type,
  :current_instances,
  :instance_limit,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_typeString

The name of an Amazon EC2 instance type. See [Amazon Elastic Compute Cloud Instance Types] for detailed descriptions.

[1]: aws.amazon.com/ec2/instance-types/

Returns:

  • (String)


5295
5296
5297
5298
5299
5300
5301
5302
# File 'lib/aws-sdk-gamelift/types.rb', line 5295

class EC2InstanceLimit < Struct.new(
  :ec2_instance_type,
  :current_instances,
  :instance_limit,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#instance_limitInteger

The number of instances that is allowed for the specified instance type and location.

Returns:

  • (Integer)


5295
5296
5297
5298
5299
5300
5301
5302
# File 'lib/aws-sdk-gamelift/types.rb', line 5295

class EC2InstanceLimit < Struct.new(
  :ec2_instance_type,
  :current_instances,
  :instance_limit,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

An Amazon Web Services Region code, such as us-west-2.

Returns:

  • (String)


5295
5296
5297
5298
5299
5300
5301
5302
# File 'lib/aws-sdk-gamelift/types.rb', line 5295

class EC2InstanceLimit < Struct.new(
  :ec2_instance_type,
  :current_instances,
  :instance_limit,
  :location)
  SENSITIVE = []
  include Aws::Structure
end