Class: Aws::GameLift::Types::FleetAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Describes an Amazon GameLift Servers fleet of game hosting resources. Attributes differ based on the fleet’s compute type, as follows:

  • EC2 fleet attributes identify a Build resource (for fleets with customer game server builds) or a Script resource (for Amazon GameLift Servers Realtime fleets).

  • Amazon GameLift Servers Anywhere fleets have an abbreviated set of attributes, because most fleet configurations are set directly on the fleet’s computes. Attributes include fleet identifiers and descriptive properties, creation/termination time, and fleet status.

**Returned by:**

docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetAttributes][1

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetAttributes

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_configurationTypes::AnywhereConfiguration

A set of attributes that are specific to an Anywhere fleet.



5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#build_arnString

The Amazon Resource Name ([ARN]) associated with the Amazon GameLift Servers build resource that is deployed on instances in this fleet. In a GameLift build ARN, the resource ID matches the BuildId value. This attribute is used with fleets where ComputeType is “EC2”.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#build_idString

A unique identifier for the build resource that is deployed on instances in this fleet. This attribute is used with fleets where ComputeType is “EC2”.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_configurationTypes::CertificateConfiguration

Determines whether a TLS/SSL certificate is generated for a fleet. This feature must be enabled when creating the fleet. All instances in a fleet share the same certificate.



5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#compute_typeString

The type of compute resource used to host your game servers. You can use your own compute resources with Amazon GameLift Servers Anywhere or use Amazon EC2 instances with managed Amazon GameLift Servers.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).

Returns:

  • (Time)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A human-readable description of the fleet.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_arnString

The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`. In a GameLift fleet ARN, the resource ID matches the FleetId value.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the fleet.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_typeString

Indicates whether the fleet uses On-Demand or Spot instances. For more information, see [ On-Demand versus Spot Instances]. This fleet property can’t be changed after the fleet is created.

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-ec2-instances.html#gamelift-ec2-instances-spot

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_role_arnString

A unique identifier for an IAM role that manages access to your Amazon Web Services services. With an instance role ARN set, any application that runs on an instance in this fleet can assume the role, including install scripts, server processes, and daemons (background processes). Create a role or look up a role’s ARN by using the [IAM dashboard] in the Amazon Web Services Management Console. Learn more about using on-box credentials for your game servers at [ Access external resources from a game server]. This attribute is used with fleets where ComputeType is EC2.

[1]: console.aws.amazon.com/iam/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-server-resources.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_role_credentials_providerString

Indicates that fleet instances maintain a shared credentials file for the IAM role defined in InstanceRoleArn. Shared credentials allow applications that are deployed with the game server executable to communicate with other Amazon Web Services resources. This property is used only when the game server is integrated with the server SDK version 5.x. For more information about using shared credentials, see [ Communicate with other Amazon Web Services resources from your fleets]. This attribute is used with fleets where ComputeType is EC2.

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-server-resources.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The Amazon EC2 instance type that the fleet uses. Instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. See [Amazon Elastic Compute Cloud Instance Types] for detailed descriptions. This attribute is used with fleets where ComputeType is EC2.

[1]: aws.amazon.com/ec2/instance-types/

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#log_pathsArray<String>

**This parameter is no longer used.** Game session log paths are now defined using the Amazon GameLift Servers server API ‘ProcessReady()` logParameters. See more information in the [Server API Reference].

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-server-api-ref.html#gamelift-sdk-server-api-ref-dataypes-process

Returns:

  • (Array<String>)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#metric_groupsArray<String>

Name of a metric group that metrics for this fleet are added to. In Amazon CloudWatch, you can view aggregated metrics for fleets that are in a metric group. A fleet can be included in only one metric group at a time. This attribute is used with fleets where ComputeType is EC2.

Returns:

  • (Array<String>)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive label that is associated with a fleet. Fleet names do not need to be unique.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#new_game_session_protection_policyString

The type of game session protection to set on all new instances that are started in the fleet. This attribute is used with fleets where ComputeType is EC2.

  • NoProtection – The game session can be terminated during a scale-down event.

  • FullProtection – If the game session is in an ACTIVE status, it cannot be terminated during a scale-down event.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#operating_systemString

The operating system of the fleet’s computing resources. A fleet’s operating system is determined by the OS of the build or script that is deployed on this fleet. This attribute is used with fleets where ComputeType is EC2.

<note markdown=“1”> Amazon Linux 2 (AL2) will reach end of support on 6/30/2026. See more details in the [Amazon Linux 2 FAQs]. For game servers that are hosted on AL2 and use server SDK version 4.x for Amazon GameLift Servers, first update the game server build to server SDK 5.x, and then deploy to AL2023 instances. See [ Migrate to server SDK version 5.]

</note>

[1]: aws.amazon.com/aws.amazon.com/amazon-linux-2/faqs/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/reference-serversdk5-migration.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#player_gateway_configurationTypes::PlayerGatewayConfiguration

Configuration settings for player gateway on this fleet.



5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#player_gateway_modeString

Indicates whether player gateway is enabled for this fleet. Player gateway provides benefits such as DDoS protection with negligible impact to latency.

If ENABLED or REQUIRED, game clients can use player gateway to connect with the game server. If DISABLED, game clients cannot use player gateway. Instead, they have to directly connect to the game server.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#resource_creation_limit_policyTypes::ResourceCreationLimitPolicy

A policy that puts limits on the number of game sessions that a player can create within a specified span of time. With this policy, you can control players’ ability to consume available resources.

The policy is evaluated when a player tries to create a new game session. On receiving a CreateGameSession request, Amazon GameLift Servers checks that the player (identified by CreatorId) has created fewer than game session limit in the specified time period.



5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#script_arnString

The Amazon Resource Name ([ARN]) associated with the GameLift script resource that is deployed on instances in this fleet. In a GameLift script ARN, the resource ID matches the ScriptId value.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#script_idString

A unique identifier for the Realtime script resource that is deployed on instances in this fleet. This attribute is used with fleets where ComputeType is “EC2”.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#server_launch_parametersString

**This parameter is no longer used.** Server launch parameters are now defined using the fleet’s runtime configuration. Requests that use this parameter continue to be valid.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#server_launch_pathString

**This parameter is no longer used.** Server launch paths are now defined using the fleet’s [RuntimeConfiguration]. Requests that use this parameter continue to be valid.

[1]: docs.aws.amazon.com/gamelift/latest/apireference/RuntimeConfiguration.html

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Current status of the fleet. Possible fleet statuses include the following:

  • NEW – A new fleet resource has been defined and Amazon GameLift Servers has started creating the fleet. Desired instances is set to 1.

  • DOWNLOADING/VALIDATING/BUILDING – Amazon GameLift Servers is download the game server build, running install scripts, and then validating the build files. When complete, Amazon GameLift Servers launches a fleet instance.

  • ACTIVATING – Amazon GameLift Servers is launching a game server process and testing its connectivity with the Amazon GameLift Servers service.

  • ACTIVE – The fleet is now ready to host game sessions.

  • ERROR – An error occurred when downloading, validating, building, or activating the fleet.

  • DELETING – Hosts are responding to a delete fleet request.

  • TERMINATED – The fleet no longer exists.

Returns:

  • (String)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_actionsArray<String>

A list of fleet activity that has been suspended using [StopFleetActions]. This includes fleet auto-scaling. This attribute is used with fleets where ComputeType is EC2.

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_StopFleetActions.html

Returns:

  • (Array<String>)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#termination_timeTime

A time stamp indicating when this data object was terminated. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).

Returns:

  • (Time)


5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-gamelift/types.rb', line 5861

class FleetAttributes < Struct.new(
  :fleet_id,
  :fleet_arn,
  :fleet_type,
  :instance_type,
  :description,
  :name,
  :creation_time,
  :termination_time,
  :status,
  :build_id,
  :build_arn,
  :script_id,
  :script_arn,
  :server_launch_path,
  :server_launch_parameters,
  :log_paths,
  :new_game_session_protection_policy,
  :operating_system,
  :resource_creation_limit_policy,
  :metric_groups,
  :stopped_actions,
  :instance_role_arn,
  :certificate_configuration,
  :compute_type,
  :anywhere_configuration,
  :instance_role_credentials_provider,
  :player_gateway_mode,
  :player_gateway_configuration)
  SENSITIVE = []
  include Aws::Structure
end