Class: Aws::GameLift::Types::FleetCapacity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Current resource capacity settings for managed EC2 fleets and managed container fleets. For multi-location fleets, location values might refer to a fleet's remote location or its home Region.

Returned by: DescribeFleetCapacity, DescribeFleetLocationCapacity, UpdateFleetCapacity

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_arnString

The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the fleet associated with the location.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#game_server_container_group_countsTypes::GameServerContainerGroupCounts

The number and status of game server container groups deployed in a container fleet.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countsTypes::EC2InstanceCounts

The current number of instances in the fleet, listed by instance status. Counts for pending and terminating instances might be non-zero if the fleet is adjusting to a scaling event or if access to resources is temporarily affected.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The Amazon EC2 instance type that is used for instances in a fleet. Instance type determines the computing resources in use, including CPU, memory, storage, and networking capacity. See Amazon Elastic Compute Cloud Instance Types for detailed descriptions.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The fleet location for the instance count information, expressed as an Amazon Web Services Region code, such as us-west-2.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#managed_capacity_configurationTypes::ManagedCapacityConfiguration

Configuration settings for managed capacity scaling.



6242
6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
# File 'lib/aws-sdk-gamelift/types.rb', line 6242

class FleetCapacity < Struct.new(
  :fleet_id,
  :fleet_arn,
  :instance_type,
  :instance_counts,
  :location,
  :game_server_container_group_counts,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end