Class: Aws::GameLift::Types::FleetDeployment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Describes a container fleet deployment with updates to the fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).

Returns:

  • (Time)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configurationTypes::DeploymentConfiguration

Instructions for how to deploy updates to a container fleet and what actions to take if the deployment fails.



6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_idString

A unique identifier for the deployment.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_statusString

The status of fleet deployment activity in the location.

  • ‘IN_PROGRESS` – The deployment is in progress.

  • ‘IMPAIRED` – The deployment failed and the fleet has some impaired containers.

  • ‘COMPLETE` – The deployment has completed successfully.

  • ‘ROLLBACK_IN_PROGRESS` – The deployment failed and rollback has been initiated.

  • ‘ROLLBACK_IN_COMPLETE` – The deployment failed and rollback has been completed.

  • ‘CANCELLED` – The deployment was cancelled.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the container fleet.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#game_server_binary_arnString

The unique identifier for the version of the game server container group definition that is being deployed.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#per_instance_binary_arnString

The unique identifier for the version of the per-instance container group definition that is being deployed.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_game_server_binary_arnString

The unique identifier for the version of the game server container group definition to roll back to if deployment fails. Amazon GameLift Servers sets this property to the container group definition version that the fleet used when it was last active.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_per_instance_binary_arnString

The unique identifier for the version of the per-instance container group definition to roll back to if deployment fails. Amazon GameLift Servers sets this property to the container group definition version that the fleet used when it was last active.

Returns:

  • (String)


6281
6282
6283
6284
6285
6286
6287
6288
6289
6290
6291
6292
6293
# File 'lib/aws-sdk-gamelift/types.rb', line 6281

class FleetDeployment < Struct.new(
  :deployment_id,
  :fleet_id,
  :game_server_binary_arn,
  :rollback_game_server_binary_arn,
  :per_instance_binary_arn,
  :rollback_per_instance_binary_arn,
  :deployment_status,
  :deployment_configuration,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end