Class: Aws::GameLift::Types::FleetUtilization
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::FleetUtilization
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Current resource utilization statistics in a specified fleet or location. The location value might refer to a fleet’s remote location or its home region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_game_session_count ⇒ Integer
The number of active game sessions that are currently being hosted across all instances in the fleet location.
-
#active_server_process_count ⇒ Integer
The number of server processes in
ACTIVEstatus that are currently running across all instances in the fleet location. -
#current_player_session_count ⇒ Integer
The number of active player sessions that are currently being hosted across all instances in the fleet location.
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it.
-
#fleet_id ⇒ String
A unique identifier for the fleet associated with the location.
-
#location ⇒ String
The fleet location for the fleet utilization information, expressed as an Amazon Web Services Region code, such as
us-west-2. -
#maximum_player_session_count ⇒ Integer
The maximum number of players allowed across all game sessions that are currently being hosted across all instances in the fleet location.
Instance Attribute Details
#active_game_session_count ⇒ Integer
The number of active game sessions that are currently being hosted across all instances in the fleet location.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#active_server_process_count ⇒ Integer
The number of server processes in ACTIVE status that are currently running across all instances in the fleet location.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#current_player_session_count ⇒ Integer
The number of active player sessions that are currently being hosted across all instances in the fleet location.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet associated with the location.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The fleet location for the fleet utilization information, expressed as an Amazon Web Services Region code, such as us-west-2.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |
#maximum_player_session_count ⇒ Integer
The maximum number of players allowed across all game sessions that are currently being hosted across all instances in the fleet location.
6110 6111 6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6110 class FleetUtilization < Struct.new( :fleet_id, :fleet_arn, :active_server_process_count, :active_game_session_count, :current_player_session_count, :maximum_player_session_count, :location) SENSITIVE = [] include Aws::Structure end |