Class: Aws::GameLift::Types::GameServerContainerDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Describes the game server container in an existing game server container group. A game server container identifies a container image with your game server build. A game server container is automatically considered essential; if an essential container fails, the entire container group restarts.

You can update a container definition and deploy the updates to an existing fleet. When creating or updating a game server container group definition, use the property [docs.aws.amazon.com/gamelift/latest/apireference/API_GameServerContainerDefinitionInput][1].

**Part of:** [ContainerGroupDefinition]

**Returned by:** [CreateContainerGroupDefinition], [DescribeContainerGroupDefinition], [ListContainerGroupDefinitions], [ListContainerGroupDefinitionVersions],

UpdateContainerGroupDefinition][7

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_GameServerContainerDefinitionInput [2]: docs.aws.amazon.com/gamelift/latest/apireference/API_ContainerGroupDefinition.html [3]: docs.aws.amazon.com/gamelift/latest/apireference/API_CreateContainerGroupDefinition.html [4]: docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeContainerGroupDefinition.html [5]: docs.aws.amazon.com/gamelift/latest/apireference/API_ListContainerGroupDefinitions.html [6]: docs.aws.amazon.com/gamelift/latest/apireference/API_ListContainerGroupDefinitionVersions.html [7]: docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateContainerGroupDefinition.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_nameString

The container definition identifier. Container names are unique within a container group definition.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#depends_onArray<Types::ContainerDependency>

Indicates that the container relies on the status of other containers in the same container group during startup and shutdown sequences. A container might have dependencies on multiple containers.

Returns:



6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#environment_overrideArray<Types::ContainerEnvironment>

A set of environment variables that’s passed to the container on startup. See the [ContainerDefinition::environment] parameter in the *Amazon Elastic Container Service API Reference*.

[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ContainerDefinition.html#ECS-Type-ContainerDefinition-environment

Returns:



6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#image_uriString

The URI to the image that Amazon GameLift Servers uses when deploying this container to a container fleet. For a more specific identifier, see ‘ResolvedImageDigest`.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#linux_capabilitiesTypes::LinuxCapabilities

Linux-specific modifications that are applied to the default Docker container configuration, such as Linux capabilities. For more information see [LinuxCapabilities].

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_LinuxCapabilities.html



6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#mount_pointsArray<Types::ContainerMountPoint>

A mount point that binds a path inside the container to a file or directory on the host system and lets it access the file or directory.

Returns:



6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#port_configurationTypes::ContainerPortConfiguration

The set of ports that are available to bind to processes in the container. For example, a game server process requires a container port to allow game clients to connect to it. Container ports aren’t directly accessed by inbound traffic. Amazon GameLift Servers maps these container ports to externally accessible connection ports, which are assigned as needed from the container fleet’s ‘ConnectionPortRange`.



6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_image_digestString

A unique and immutable identifier for the container image. The digest is a SHA 256 hash of the container image manifest.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end

#server_sdk_versionString

The Amazon GameLift Servers server SDK version that the game server is integrated with. Only game servers using 5.2.0 or higher are compatible with container fleets.

Returns:

  • (String)


6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
# File 'lib/aws-sdk-gamelift/types.rb', line 6640

class GameServerContainerDefinition < Struct.new(
  :container_name,
  :depends_on,
  :mount_points,
  :environment_override,
  :image_uri,
  :port_configuration,
  :resolved_image_digest,
  :server_sdk_version,
  :linux_capabilities)
  SENSITIVE = []
  include Aws::Structure
end