Class: Aws::GameLift::Types::GameSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GameSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Properties describing a game session.
A game session in ACTIVE status can host players. When a game session ends, its status is set to ‘TERMINATED`.
Amazon GameLift Servers retains a game session resource for 30 days after the game session ends. You can reuse idempotency token values after this time. Game session logs are retained for 14 days.
Constant Summary collapse
- SENSITIVE =
[:ip_address, :port]
Instance Attribute Summary collapse
-
#compute_name ⇒ String
A descriptive label for the compute resource.
-
#creation_time ⇒ Time
A time stamp indicating when this data object was created.
-
#creator_id ⇒ String
A unique identifier for a player.
-
#current_player_session_count ⇒ Integer
Number of players currently in the game session.
-
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session.
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) associated with the GameLift fleet that this game session is running on.
-
#fleet_id ⇒ String
A unique identifier for the fleet that the game session is running on.
-
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session.
-
#game_session_data ⇒ String
A set of custom game session properties, formatted as a single string value.
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions.
-
#ip_address ⇒ String
The IP address of the game session.
-
#location ⇒ String
The fleet location where the game session is running.
-
#matchmaker_data ⇒ String
Information about the matchmaking process that resulted in the game session, if matchmaking was used.
-
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
-
#name ⇒ String
A descriptive label that is associated with a game session.
-
#player_gateway_status ⇒ String
Indicates whether player gateway is available for use for this game session.
-
#player_session_creation_policy ⇒ String
Indicates whether the game session is accepting new players.
-
#port ⇒ Integer
The port number for the game session.
-
#status ⇒ String
Current status of the game session.
-
#status_reason ⇒ String
Provides additional information about game session status.
-
#termination_time ⇒ Time
A time stamp indicating when this data object was terminated.
Instance Attribute Details
#compute_name ⇒ String
A descriptive label for the compute resource. The compute resource that is hosting the game session. For EC2 fleets, this is the EC2 instance ID. For Container fleets, each game server container group on a fleet instance is assigned a compute name. For Anywhere fleets, this is the custom compute name.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#creation_time ⇒ Time
A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#creator_id ⇒ String
A unique identifier for a player. This ID is used to enforce a resource protection policy (if one exists), that limits the number of game sessions a player can create.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#current_player_session_count ⇒ Integer
Number of players currently in the game session.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session. Values have the following format:
-
TLS-enabled fleets: ‘<unique identifier>.<region identifier>.amazongamelift.com`.
-
Non-TLS-enabled fleets: ‘ec2-<unique identifier>.compute.amazonaws.com`. (See [Amazon EC2 Instance IP Addressing].)
When connecting to a game session that is running on a TLS-enabled fleet, you must use the DNS name, not the IP address.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#concepts-public-addresses
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) associated with the GameLift fleet that this game session is running on.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that the game session is running on.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session. For example: ‘“difficulty”, “Value”: “novice”`.
<note markdown=“1”> * Avoid using periods (“.”) in property keys if you plan to search
for game sessions by properties. Property keys containing periods
cannot be searched and will be filtered out from search results
due to search index limitations.
-
If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.
</note>
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#game_session_data ⇒ String
A set of custom game session properties, formatted as a single string value. This data is passed to a game server process with a request to start a new game session. For more information, see [Start a game session].
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions. The value is always a full ARN in the following format: For Home Region game session - ‘arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<ID string>`. For Remote Location game session - `arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<location>/<ID string>`.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#location ⇒ String
The fleet location where the game session is running. This value might specify the fleet’s home Region or a remote location. Location is expressed as an Amazon Web Services Region code such as ‘us-west-2`.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#matchmaker_data ⇒ String
Information about the matchmaking process that resulted in the game session, if matchmaking was used. Data is in JSON syntax, formatted as a string. Information includes the matchmaker ID as well as player attributes and team assignments. For more details on matchmaker data, see [Match Data]. Matchmaker data is updated whenever new players are added during a successful backfill (see [StartMatchBackfill]).
[1]: docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-server.html#match-server-data [2]: docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchBackfill.html
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#name ⇒ String
A descriptive label that is associated with a game session. Session names do not need to be unique.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#player_gateway_status ⇒ String
Indicates whether player gateway is available for use for this game session. Note, even if a fleet has PlayerGatewayMode configured as ‘ENABLED`, player gateway might not be available in a specific location. For more information about locations where player gateway is supported, see [Amazon GameLift Servers service locations].
Possible values include:
-
‘ENABLED` – Player gateway is available for routing player connections for this game session.
-
‘DISABLED` – Player gateway is not available for this game session.
[1]: docs.aws.amazon.com/gameliftservers/latest/developerguide/gamelift-regions.html
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#player_session_creation_policy ⇒ String
Indicates whether the game session is accepting new players.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#port ⇒ Integer
The port number for the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#status ⇒ String
Current status of the game session. A game session must have an ‘ACTIVE` status to have player sessions.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#status_reason ⇒ String
Provides additional information about game session status.
-
‘INTERRUPTED` – The game session was hosted on an EC2 Spot instance that was reclaimed, causing the active game session to be stopped.
-
‘TRIGGERED_ON_PROCESS_TERMINATE` – The game session was stopped by calling `TerminateGameSession` with the termination mode `TRIGGER_ON_PROCESS_TERMINATE`.
-
‘FORCE_TERMINATED` – The game session was stopped by calling `TerminateGameSession` with the termination mode `FORCE_TERMINATE`.
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#termination_time ⇒ Time
A time stamp indicating when this data object was terminated. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).
7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7249 class GameSession < Struct.new( :game_session_id, :name, :fleet_id, :fleet_arn, :creation_time, :termination_time, :current_player_session_count, :maximum_player_session_count, :status, :status_reason, :game_properties, :ip_address, :dns_name, :port, :player_session_creation_policy, :creator_id, :game_session_data, :matchmaker_data, :location, :compute_name, :player_gateway_status) SENSITIVE = [:ip_address, :port] include Aws::Structure end |