Class: Aws::GameLift::Types::GameSessionConnectionInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GameSessionConnectionInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Connection information for a new game session that is created in response to a start matchmaking request. Once a match is made, the FlexMatch engine creates a new game session for it. This information, including the game session endpoint and player sessions for each player in the original matchmaking request, is added to the matchmaking ticket.
Constant Summary collapse
- SENSITIVE =
[:ip_address]
Instance Attribute Summary collapse
-
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session.
-
#game_session_arn ⇒ String
A unique identifier for the game session.
-
#ip_address ⇒ String
The IP address of the game session.
-
#matched_player_sessions ⇒ Array<Types::MatchedPlayerSession>
A collection of player session IDs, one for each player ID that was included in the original matchmaking request.
-
#player_gateway_status ⇒ String
The current status of player gateway for the game session.
-
#port ⇒ Integer
The port number for the game session.
Instance Attribute Details
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session. Values have the following format:
-
TLS-enabled fleets: ‘<unique identifier>.<region identifier>.amazongamelift.com`.
-
Non-TLS-enabled fleets: ‘ec2-<unique identifier>.compute.amazonaws.com`. (See [Amazon EC2 Instance IP Addressing].)
When connecting to a game session that is running on a TLS-enabled fleet, you must use the DNS name, not the IP address.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#concepts-public-addresses
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |
#game_session_arn ⇒ String
A unique identifier for the game session. Use the game session ID.
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |
#matched_player_sessions ⇒ Array<Types::MatchedPlayerSession>
A collection of player session IDs, one for each player ID that was included in the original matchmaking request.
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |
#player_gateway_status ⇒ String
The current status of player gateway for the game session. Note, even if a fleet has PlayerGatewayMode configured as ENABLED, player gateway might not be available in a specific location. For more information about locations where player gateway is supported, see [supported locations].
Possible values include:
-
ENABLED– Player gateway is available for this game session. -
DISABLED– Player gateway is not available for this game session.
[1]: docs.aws.amazon.com/gameliftservers/latest/developerguide/gamelift-regions.html
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |
#port ⇒ Integer
The port number for the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.
7030 7031 7032 7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7030 class GameSessionConnectionInfo < Struct.new( :game_session_arn, :ip_address, :dns_name, :port, :matched_player_sessions, :player_gateway_status) SENSITIVE = [:ip_address] include Aws::Structure end |