Class: Aws::GameLift::Types::GetComputeAccessInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetComputeAccessInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_name ⇒ String
A unique identifier for the compute resource that you want to connect to.
-
#fleet_id ⇒ String
A unique identifier for the fleet that holds the compute resource that you want to connect to.
Instance Attribute Details
#compute_name ⇒ String
A unique identifier for the compute resource that you want to connect to. For an EC2 fleet, use an instance ID. For a managed container fleet, use a compute name. You can retrieve a fleet's compute names by calling ListCompute.
7823 7824 7825 7826 7827 7828 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7823 class GetComputeAccessInput < Struct.new( :fleet_id, :compute_name) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that holds the compute resource that you want to connect to. You can use either the fleet ID or ARN value.
7823 7824 7825 7826 7827 7828 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7823 class GetComputeAccessInput < Struct.new( :fleet_id, :compute_name) SENSITIVE = [] include Aws::Structure end |