Class: Aws::GameLift::Types::GetComputeAccessOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:credentials]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_arnString

The Amazon Resource Name ([ARN]) that is assigned to an Amazon GameLift Servers compute resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::compute/compute-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#compute_nameString

The identifier of the compute resource to be accessed. This value might be either a compute name or an instance ID.

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#container_identifiersArray<Types::ContainerIdentifier>

For a managed container fleet, a list of containers on the compute. Use the container runtime ID with Docker commands to connect to a specific container.

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#credentialsTypes::AwsCredentials

A set of temporary Amazon Web Services credentials for use when connecting to the compute resource with Amazon EC2 Systems Manager (SSM).

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#fleet_arnString

The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#fleet_idString

The ID of the fleet that holds the compute resource to be accessed.

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end

#targetString

The instance ID where the compute resource is running.

Returns:



7534
7535
7536
7537
7538
7539
7540
7541
7542
7543
7544
# File 'lib/aws-sdk-gamelift/types.rb', line 7534

class GetComputeAccessOutput < Struct.new(
  :fleet_id,
  :fleet_arn,
  :compute_name,
  :compute_arn,
  :credentials,
  :target,
  :container_identifiers)
  SENSITIVE = [:credentials]
  include Aws::Structure
end