Class: Aws::GameLift::Types::GetComputeAuthTokenInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetComputeAuthTokenInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_name ⇒ String
The name of the compute resource you are requesting the authentication token for.
-
#fleet_id ⇒ String
A unique identifier for the fleet that the compute is registered to.
Instance Attribute Details
#compute_name ⇒ String
The name of the compute resource you are requesting the authentication token for. For an Anywhere fleet compute, use the registered compute name. For an EC2 fleet instance, use the instance ID.
7559 7560 7561 7562 7563 7564 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7559 class GetComputeAuthTokenInput < Struct.new( :fleet_id, :compute_name) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that the compute is registered to.
7559 7560 7561 7562 7563 7564 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7559 class GetComputeAuthTokenInput < Struct.new( :fleet_id, :compute_name) SENSITIVE = [] include Aws::Structure end |