Class: Aws::GameLift::Types::GetGameSessionLogUrlInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetGameSessionLogUrlInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to get logs for.
Instance Attribute Details
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to get logs for. The value is always a full ARN in the following format: For Home Region game session - ‘arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<ID string>`. For Remote Location game session - `arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<location>/<ID string>`.
7964 7965 7966 7967 7968 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7964 class GetGameSessionLogUrlInput < Struct.new( :game_session_id) SENSITIVE = [] include Aws::Structure end |