Class: Aws::GameLift::Types::GetPlayerConnectionDetailsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetPlayerConnectionDetailsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:player_ids]
Instance Attribute Summary collapse
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions for which to retrieve player connection details.
-
#player_ids ⇒ Array<String>
List of unique identifiers for players.
Instance Attribute Details
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions for which to retrieve player connection details. The value is always a full ARN in the following format: For Home Region game session - ‘arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<ID string>`. For Remote Location game session - `arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<location>/<ID string>`.
8041 8042 8043 8044 8045 8046 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8041 class GetPlayerConnectionDetailsInput < Struct.new( :game_session_id, :player_ids) SENSITIVE = [:player_ids] include Aws::Structure end |
#player_ids ⇒ Array<String>
List of unique identifiers for players. Connection details are returned for each player in this list.
8041 8042 8043 8044 8045 8046 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8041 class GetPlayerConnectionDetailsInput < Struct.new( :game_session_id, :player_ids) SENSITIVE = [:player_ids] include Aws::Structure end |