Class: Aws::GameLift::Types::GetPlayerConnectionDetailsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_session_idString

An identifier for the game session that is unique across all regions for which the player connection details were retrieved. The value is always a full ARN in the following format: For Home Region game session - ‘arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<ID string>`. For Remote Location game session - `arn:aws:gamelift:<home_region>::gamesession/<fleet ID>/<location>/<ID string>`.

Returns:

  • (String)


8065
8066
8067
8068
8069
8070
# File 'lib/aws-sdk-gamelift/types.rb', line 8065

class GetPlayerConnectionDetailsOutput < Struct.new(
  :game_session_id,
  :player_connection_details)
  SENSITIVE = []
  include Aws::Structure
end

#player_connection_detailsArray<Types::PlayerConnectionDetail>

A collection of player connection detail objects, one for each requested player.

Returns:



8065
8066
8067
8068
8069
8070
# File 'lib/aws-sdk-gamelift/types.rb', line 8065

class GetPlayerConnectionDetailsOutput < Struct.new(
  :game_session_id,
  :player_connection_details)
  SENSITIVE = []
  include Aws::Structure
end