Class: Aws::GameLift::Types::Instance
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::Instance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Represents a virtual computing instance that runs game server processes and hosts game sessions. In Amazon GameLift Servers, one or more instances make up a managed EC2 fleet.
Constant Summary collapse
- SENSITIVE =
[:ip_address]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
A time stamp indicating when this data object was created.
-
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session.
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it.
-
#fleet_id ⇒ String
A unique identifier for the fleet that the instance belongs to.
-
#instance_id ⇒ String
A unique identifier for the instance.
-
#ip_address ⇒ String
IP address that is assigned to the instance.
-
#location ⇒ String
The fleet location of the instance, expressed as an Amazon Web Services Region code, such as ‘us-west-2`.
-
#operating_system ⇒ String
Operating system that is running on this EC2 instance.
-
#status ⇒ String
Current status of the instance.
-
#type ⇒ String
EC2 instance type that defines the computing resources of this instance.
Instance Attribute Details
#creation_time ⇒ Time
A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session. Values have the following format:
-
TLS-enabled fleets: ‘<unique identifier>.<region identifier>.amazongamelift.com`.
-
Non-TLS-enabled fleets: ‘ec2-<unique identifier>.compute.amazonaws.com`. (See [Amazon EC2 Instance IP Addressing].)
When connecting to a game session that is running on a TLS-enabled fleet, you must use the DNS name, not the IP address.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#concepts-public-addresses
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that the instance belongs to.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#instance_id ⇒ String
A unique identifier for the instance.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#ip_address ⇒ String
IP address that is assigned to the instance.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#location ⇒ String
The fleet location of the instance, expressed as an Amazon Web Services Region code, such as ‘us-west-2`.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#operating_system ⇒ String
Operating system that is running on this EC2 instance.
<note markdown=“1”> Amazon Linux 2 (AL2) will reach end of support on 6/30/2026. See more details in the [Amazon Linux 2 FAQs]. For game servers that are hosted on AL2 and use server SDK version 4.x for Amazon GameLift Servers, first update the game server build to server SDK 5.x, and then deploy to AL2023 instances. See [ Migrate to server SDK version 5.]
</note>
[1]: aws.amazon.com/aws.amazon.com/amazon-linux-2/faqs/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/reference-serversdk5-migration.html
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#status ⇒ String
Current status of the instance. Possible statuses include the following:
-
PENDING – The instance is in the process of being created and launching server processes as defined in the fleet’s run-time configuration.
-
ACTIVE – The instance has been successfully created and at least one server process has successfully launched and reported back to Amazon GameLift Servers that it is ready to host a game session. The instance is now considered ready to host game sessions.
-
TERMINATING – The instance is in the process of shutting down. This may happen to reduce capacity during a scaling down event or to recycle resources in the event of a problem.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |
#type ⇒ String
EC2 instance type that defines the computing resources of this instance.
8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 8105 8106 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8093 class Instance < Struct.new( :fleet_id, :fleet_arn, :instance_id, :ip_address, :dns_name, :operating_system, :type, :status, :creation_time, :location) SENSITIVE = [:ip_address] include Aws::Structure end |