Class: Aws::GameLift::Types::InstanceDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::InstanceDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
An allowed instance type for a game server group. All game server groups must have at least two instance types defined for it. Amazon GameLift Servers FleetIQ periodically evaluates each defined instance type for viability. It then updates the Auto Scaling group with the list of viable instance types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_type ⇒ String
An Amazon EC2 instance type designation.
-
#weighted_capacity ⇒ String
Instance weighting that indicates how much this instance type contributes to the total capacity of a game server group.
Instance Attribute Details
#instance_type ⇒ String
An Amazon EC2 instance type designation.
8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8206 class InstanceDefinition < Struct.new( :instance_type, :weighted_capacity) SENSITIVE = [] include Aws::Structure end |
#weighted_capacity ⇒ String
Instance weighting that indicates how much this instance type contributes to the total capacity of a game server group. Instance weights are used by Amazon GameLift Servers FleetIQ to calculate the instance type’s cost per unit hour and better identify the most cost-effective options. For detailed information on weighting instance capacity, see [Instance Weighting] in the *Amazon Elastic Compute Cloud Auto Scaling User Guide*. Default value is “1”.
[1]: docs.aws.amazon.com/autoscaling/ec2/userguide/asg-instance-weighting.html
8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8206 class InstanceDefinition < Struct.new( :instance_type, :weighted_capacity) SENSITIVE = [] include Aws::Structure end |