Class: Aws::GameLift::Types::IpPermission
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::IpPermission
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
A range of IP addresses and port settings that allow inbound traffic to connect to processes on an instance in a fleet. Processes are assigned an IP address/port number combination, which must fall into the fleet’s allowed ranges.
For Amazon GameLift Servers Realtime fleets, Amazon GameLift Servers automatically opens two port ranges, one for TCP messaging and one for UDP.
Constant Summary collapse
- SENSITIVE =
[:from_port, :to_port, :ip_range]
Instance Attribute Summary collapse
-
#from_port ⇒ Integer
A starting value for a range of allowed port numbers.
-
#ip_range ⇒ String
A range of allowed IP addresses.
-
#protocol ⇒ String
The network communication protocol used by the fleet.
-
#to_port ⇒ Integer
An ending value for a range of allowed port numbers.
Instance Attribute Details
#from_port ⇒ Integer
A starting value for a range of allowed port numbers.
For fleets using Linux builds, only ports ‘22` and `1026-60000` are valid.
For fleets using Windows builds, only ports ‘1026-60000` are valid.
8407 8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8407 class IpPermission < Struct.new( :from_port, :to_port, :ip_range, :protocol) SENSITIVE = [:from_port, :to_port, :ip_range] include Aws::Structure end |
#ip_range ⇒ String
A range of allowed IP addresses. This value must be expressed in CIDR notation. Example: “‘000.000.000.000/[subnet mask]`” or optionally the shortened version “`0.0.0.0/[subnet mask]`”.
8407 8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8407 class IpPermission < Struct.new( :from_port, :to_port, :ip_range, :protocol) SENSITIVE = [:from_port, :to_port, :ip_range] include Aws::Structure end |
#protocol ⇒ String
The network communication protocol used by the fleet.
8407 8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8407 class IpPermission < Struct.new( :from_port, :to_port, :ip_range, :protocol) SENSITIVE = [:from_port, :to_port, :ip_range] include Aws::Structure end |
#to_port ⇒ Integer
An ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be equal to or greater than ‘FromPort`.
For fleets using Linux builds, only ports ‘22` and `1026-60000` are valid.
For fleets using Windows builds, only ports ‘1026-60000` are valid.
8407 8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8407 class IpPermission < Struct.new( :from_port, :to_port, :ip_range, :protocol) SENSITIVE = [:from_port, :to_port, :ip_range] include Aws::Structure end |