Class: Aws::GameLift::Types::LinuxCapabilities

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

A set of Linux capabilities that are added to a container’s default Docker configuration for a container defined in the [ContainerGroupDefinition]. For more detailed information about these Linux capabilities, see the [capabilities(7)] Linux manual page.

**Modifying capabilities on an existing container:** To remove a capability, update the ‘Include` list with only the needed capabilities. To revert back to default capabilities, omit `LinuxCapabilities` within the ContainerDefinition.

Part of: [GameServerContainerDefinition], [GameServerContainerDefinitionInput],

SupportContainerDefinition], [SupportContainerDefinitionInput][6

Returned by: [CreateContainerGroupDefinition], [DescribeContainerGroupDefinition], [ListContainerGroupDefinitions], [ListContainerGroupDefinitionVersions],

UpdateContainerGroupDefinition][11

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_ContainerGroupDefinition.html [2]: man7.org/linux/man-pages/man7/capabilities.7.html [3]: docs.aws.amazon.com/gamelift/latest/apireference/API_GameServerContainerDefinition.html [4]: docs.aws.amazon.com/gamelift/latest/apireference/API_GameServerContainerDefinitionInput.html [5]: docs.aws.amazon.com/gamelift/latest/apireference/API_SupportContainerDefinition.html [6]: docs.aws.amazon.com/gamelift/latest/apireference/API_SupportContainerDefinitionInput.html [7]: docs.aws.amazon.com/gamelift/latest/apireference/API_CreateContainerGroupDefinition.html [8]: docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeContainerGroupDefinition.html [9]: docs.aws.amazon.com/gamelift/latest/apireference/API_ListContainerGroupDefinitions.html [10]: docs.aws.amazon.com/gamelift/latest/apireference/API_ListContainerGroupDefinitionVersions.html [11]: docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateContainerGroupDefinition.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#includeArray<String>

The list of Linux capabilities to add to the container’s default configuration. Specify each capability as a string from the set of supported capability names (for example, ‘NET_BIND_SERVICE` or `SYS_PTRACE`).

Returns:

  • (Array<String>)


8504
8505
8506
8507
8508
# File 'lib/aws-sdk-gamelift/types.rb', line 8504

class LinuxCapabilities < Struct.new(
  :include)
  SENSITIVE = []
  include Aws::Structure
end