Class: Aws::GameLift::Types::ListComputeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListComputeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_list ⇒ Array<Types::Compute>
A list of compute resources in the specified fleet.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#compute_list ⇒ Array<Types::Compute>
A list of compute resources in the specified fleet.
8713 8714 8715 8716 8717 8718 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8713 class ListComputeOutput < Struct.new( :compute_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8713 8714 8715 8716 8717 8718 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8713 class ListComputeOutput < Struct.new( :compute_list, :next_token) SENSITIVE = [] include Aws::Structure end |