Class: Aws::GameLift::Types::ListContainerFleetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListContainerFleetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_group_definition_name ⇒ String
The container group definition to filter the list on.
-
#limit ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
Instance Attribute Details
#container_group_definition_name ⇒ String
The container group definition to filter the list on. Use this parameter to retrieve only those fleets that use the specified container group definition. You can specify the container group definition's name to get fleets with the latest versions. Alternatively, provide an ARN value to get fleets with a specific version number.
8743 8744 8745 8746 8747 8748 8749 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8743 class ListContainerFleetsInput < Struct.new( :container_group_definition_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
8743 8744 8745 8746 8747 8748 8749 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8743 class ListContainerFleetsInput < Struct.new( :container_group_definition_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
8743 8744 8745 8746 8747 8748 8749 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8743 class ListContainerFleetsInput < Struct.new( :container_group_definition_name, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |