Class: Aws::GameLift::Types::ListContainerGroupDefinitionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListContainerGroupDefinitionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_group_type ⇒ String
The type of container group to retrieve.
-
#limit ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
A token that indicates the start of the next sequential page of results.
Instance Attribute Details
#container_group_type ⇒ String
The type of container group to retrieve. Container group type determines how Amazon GameLift Servers deploys the container group on each fleet instance.
8426 8427 8428 8429 8430 8431 8432 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8426 class ListContainerGroupDefinitionsInput < Struct.new( :container_group_type, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.
8426 8427 8428 8429 8430 8431 8432 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8426 class ListContainerGroupDefinitionsInput < Struct.new( :container_group_type, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.
8426 8427 8428 8429 8430 8431 8432 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8426 class ListContainerGroupDefinitionsInput < Struct.new( :container_group_type, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |