Class: Aws::GameLift::Types::ListFleetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListFleetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_ids ⇒ Array<String>
A set of fleet IDs that match the list request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#fleet_ids ⇒ Array<String>
A set of fleet IDs that match the list request.
8957 8958 8959 8960 8961 8962 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8957 class ListFleetsOutput < Struct.new( :fleet_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8957 8958 8959 8960 8961 8962 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8957 class ListFleetsOutput < Struct.new( :fleet_ids, :next_token) SENSITIVE = [] include Aws::Structure end |