Class: Aws::GameLift::Types::ListGameServersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_server_group_nameString

An identifier for the game server group to retrieve a list of game servers from. Use either the name or ARN value.

Returns:

  • (String)


8616
8617
8618
8619
8620
8621
8622
8623
# File 'lib/aws-sdk-gamelift/types.rb', line 8616

class ListGameServersInput < Struct.new(
  :game_server_group_name,
  :sort_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


8616
8617
8618
8619
8620
8621
8622
8623
# File 'lib/aws-sdk-gamelift/types.rb', line 8616

class ListGameServersInput < Struct.new(
  :game_server_group_name,
  :sort_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.

Returns:

  • (String)


8616
8617
8618
8619
8620
8621
8622
8623
# File 'lib/aws-sdk-gamelift/types.rb', line 8616

class ListGameServersInput < Struct.new(
  :game_server_group_name,
  :sort_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Indicates how to sort the returned data based on game server registration timestamp. Use ASCENDING to retrieve oldest game servers first, or use DESCENDING to retrieve newest game servers first. If this parameter is left empty, game servers are returned in no particular order.

Returns:

  • (String)


8616
8617
8618
8619
8620
8621
8622
8623
# File 'lib/aws-sdk-gamelift/types.rb', line 8616

class ListGameServersInput < Struct.new(
  :game_server_group_name,
  :sort_order,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end