Class: Aws::GameLift::Types::ListGameServersOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListGameServersOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_servers ⇒ Array<Types::GameServer>
A collection of game server objects that match the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_servers ⇒ Array<Types::GameServer>
A collection of game server objects that match the request.
8637 8638 8639 8640 8641 8642 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8637 class ListGameServersOutput < Struct.new( :game_servers, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8637 8638 8639 8640 8641 8642 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8637 class ListGameServersOutput < Struct.new( :game_servers, :next_token) SENSITIVE = [] include Aws::Structure end |