Class: Aws::GameLift::Types::ListScriptsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListScriptsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
-
#scripts ⇒ Array<Types::Script>
A set of properties describing the requested script.
Instance Attribute Details
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8728 8729 8730 8731 8732 8733 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8728 class ListScriptsOutput < Struct.new( :scripts, :next_token) SENSITIVE = [] include Aws::Structure end |
#scripts ⇒ Array<Types::Script>
A set of properties describing the requested script.
8728 8729 8730 8731 8732 8733 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8728 class ListScriptsOutput < Struct.new( :scripts, :next_token) SENSITIVE = [] include Aws::Structure end |