Class: Aws::GameLift::Types::LocationState
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::LocationState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
A fleet location and its life-cycle state. A location state object might be used to describe a fleet’s remote location or home Region. Life-cycle state tracks the progress of launching the first instance in a new location and preparing it for game hosting, and then removing all instances and deleting the location from the fleet.
-
NEW – A new fleet location has been defined and desired instances is set to 1.
-
DOWNLOADING/VALIDATING/BUILDING/ACTIVATING – Amazon GameLift Servers is setting up the new fleet location, creating new instances with the game build or Realtime script and starting server processes.
-
ACTIVE – Hosts can now accept game sessions.
-
ERROR – An error occurred when downloading, validating, building, or activating the fleet location.
-
DELETING – Hosts are responding to a delete fleet location request.
-
TERMINATED – The fleet location no longer exists.
-
NOT_FOUND – The fleet location was not found. This could be because the custom location was removed or not created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location ⇒ String
The fleet location, expressed as an Amazon Web Services Region code such as
us-west-2. -
#player_gateway_status ⇒ String
The current status of player gateway in this location for this fleet.
-
#status ⇒ String
The life-cycle status of a fleet location.
Instance Attribute Details
#location ⇒ String
The fleet location, expressed as an Amazon Web Services Region code such as us-west-2.
8905 8906 8907 8908 8909 8910 8911 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8905 class LocationState < Struct.new( :location, :status, :player_gateway_status) SENSITIVE = [] include Aws::Structure end |
#player_gateway_status ⇒ String
The current status of player gateway in this location for this fleet. Note, even if a fleet has PlayerGatewayMode configured as ENABLED, player gateway might not be available in a specific location. For more information about locations where player gateway is supported, see [Amazon GameLift Servers service locations].
Possible values include:
-
ENABLED– Player gateway is available for this fleet location. -
DISABLED– Player gateway is not available for this fleet location.
[1]: docs.aws.amazon.com/gameliftservers/latest/developerguide/gamelift-regions.html
8905 8906 8907 8908 8909 8910 8911 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8905 class LocationState < Struct.new( :location, :status, :player_gateway_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The life-cycle status of a fleet location.
8905 8906 8907 8908 8909 8910 8911 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8905 class LocationState < Struct.new( :location, :status, :player_gateway_status) SENSITIVE = [] include Aws::Structure end |