Class: Aws::GameLift::Types::LocationalDeployment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

For a multi-location container fleet, describes the progress of a deployment across all fleet locations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_statusString

The status of fleet deployment activity in the location.

  • IN_PROGRESS – The deployment is in progress.

  • IMPAIRED – The deployment failed and the fleet has some impaired containers.

  • COMPLETE – The deployment has completed successfully.

  • ROLLBACK_IN_PROGRESS – The deployment failed and rollback has been initiated.

  • ROLLBACK_IN_COMPLETE – The deployment failed and rollback has been completed.

  • CANCELLED – The deployment was cancelled.

Returns:

  • (String)


8937
8938
8939
8940
8941
# File 'lib/aws-sdk-gamelift/types.rb', line 8937

class LocationalDeployment < Struct.new(
  :deployment_status)
  SENSITIVE = []
  include Aws::Structure
end