Class: Aws::GameLift::Types::LogConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::LogConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
A method for collecting container logs for the fleet. Amazon GameLift Servers saves all standard output for each container in logs, including game session logs. You can select from the following methods:
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_destination ⇒ String
The type of log collection to use for a fleet.
-
#log_group_arn ⇒ String
If log destination is
CLOUDWATCH, logs are sent to the specified log group in Amazon CloudWatch. -
#s3_bucket_name ⇒ String
If log destination is
S3, logs are sent to the specified Amazon S3 bucket name.
Instance Attribute Details
#log_destination ⇒ String
The type of log collection to use for a fleet.
-
CLOUDWATCH– (default value) Send logs to an Amazon CloudWatch log group that you define. Each container emits a log stream, which is organized in the log group. -
S3– Store logs in an Amazon S3 bucket that you define. This bucket must reside in the fleet’s home Amazon Web Services Region. -
NONE– Don’t collect container logs.
8974 8975 8976 8977 8978 8979 8980 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8974 class LogConfiguration < Struct.new( :log_destination, :s3_bucket_name, :log_group_arn) SENSITIVE = [] include Aws::Structure end |
#log_group_arn ⇒ String
If log destination is CLOUDWATCH, logs are sent to the specified log group in Amazon CloudWatch.
8974 8975 8976 8977 8978 8979 8980 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8974 class LogConfiguration < Struct.new( :log_destination, :s3_bucket_name, :log_group_arn) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
If log destination is S3, logs are sent to the specified Amazon S3 bucket name.
8974 8975 8976 8977 8978 8979 8980 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8974 class LogConfiguration < Struct.new( :log_destination, :s3_bucket_name, :log_group_arn) SENSITIVE = [] include Aws::Structure end |