Class: Aws::GameLift::Types::Player
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::Player
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Represents a player in matchmaking. When starting a matchmaking request, a player has a player ID, attributes, and may have latency data. Team information is added after a match has been successfully completed.
Constant Summary collapse
- SENSITIVE =
[:player_id]
Instance Attribute Summary collapse
-
#latency_in_ms ⇒ Hash<String,Integer>
A set of values, expressed in milliseconds, that indicates the amount of latency that a player experiences when connected to a fleet location (Amazon Web Services Regions or custom locations for Amazon GameLift Servers Anywhere fleets).
-
#player_attributes ⇒ Hash<String,Types::AttributeValue>
A collection of key:value pairs containing player information for use in matchmaking.
-
#player_id ⇒ String
A unique identifier for a player.
-
#team ⇒ String
Name of the team that the player is assigned to in a match.
Instance Attribute Details
#latency_in_ms ⇒ Hash<String,Integer>
A set of values, expressed in milliseconds, that indicates the amount of latency that a player experiences when connected to a fleet location (Amazon Web Services Regions or custom locations for Amazon GameLift Servers Anywhere fleets). If this property is present, FlexMatch considers placing the match only in Regions for which latency is reported.
If a matchmaker has a rule that evaluates player latency, players must report latency in order to be matched. If no latency is reported in this scenario, FlexMatch assumes that no Regions are available to the player and the ticket is not matchable.
10006 10007 10008 10009 10010 10011 10012 10013 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10006 class Player < Struct.new( :player_id, :player_attributes, :team, :latency_in_ms) SENSITIVE = [:player_id] include Aws::Structure end |
#player_attributes ⇒ Hash<String,Types::AttributeValue>
A collection of key:value pairs containing player information for
use in matchmaking. Player attribute keys must match the
playerAttributes used in a matchmaking rule set. Example:
"PlayerAttributes": {"skill": {"N": "23"}, "gameMode": {"S": "deathmatch"}}.
You can provide up to 10 PlayerAttributes.
10006 10007 10008 10009 10010 10011 10012 10013 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10006 class Player < Struct.new( :player_id, :player_attributes, :team, :latency_in_ms) SENSITIVE = [:player_id] include Aws::Structure end |
#player_id ⇒ String
A unique identifier for a player
10006 10007 10008 10009 10010 10011 10012 10013 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10006 class Player < Struct.new( :player_id, :player_attributes, :team, :latency_in_ms) SENSITIVE = [:player_id] include Aws::Structure end |
#team ⇒ String
Name of the team that the player is assigned to in a match. Team names are defined in a matchmaking rule set.
10006 10007 10008 10009 10010 10011 10012 10013 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10006 class Player < Struct.new( :player_id, :player_attributes, :team, :latency_in_ms) SENSITIVE = [:player_id] include Aws::Structure end |