Class: Aws::GameLift::Types::PlayerConnectionDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Connection information for a game client to connect to a game session. This object contains the IP address(es), port(s), and authentication details your game client needs to establish a connection.

**With player gateway enabled:** Contains relay endpoints and a player gateway token. Your game client must prepend player gateway token to each payload for validation and connection through relay endpoints.

**With player gateway disabled:** Contains game server endpoint. Player gateway token and expiration fields are empty.

Constant Summary collapse

SENSITIVE =
[:player_id]

Instance Attribute Summary collapse

Instance Attribute Details

#endpointsArray<Types::PlayerConnectionEndpoint>

List of connection endpoints for the game client. Your game client uses these IP address(es) and port(s) to connect to the game session.

When player gateway is enabled, these are relay endpoints with benefits such as DDoS protection. When disabled, this is the game server endpoint.



9646
9647
9648
9649
9650
9651
9652
9653
# File 'lib/aws-sdk-gamelift/types.rb', line 9646

class PlayerConnectionDetail < Struct.new(
  :player_id,
  :endpoints,
  :player_gateway_token,
  :expiration)
  SENSITIVE = [:player_id]
  include Aws::Structure
end

#expirationTime

When player gateway is enabled, this is the timestamp indicating when player gateway token expires. Your game backend should call

GetPlayerConnectionDetails][1

to retrieve fresh connection

information for your game clients before this time. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).

This value is empty when player gateway is disabled.

[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_GetPlayerConnectionDetails.html

Returns:

  • (Time)


9646
9647
9648
9649
9650
9651
9652
9653
# File 'lib/aws-sdk-gamelift/types.rb', line 9646

class PlayerConnectionDetail < Struct.new(
  :player_id,
  :endpoints,
  :player_gateway_token,
  :expiration)
  SENSITIVE = [:player_id]
  include Aws::Structure
end

#player_gateway_tokenString

Access token that your game client must prepend to all traffic sent through player gateway. Player gateway verifies identity and authorizes connection based on this token.

This value is empty when player gateway is disabled.

Returns:

  • (String)


9646
9647
9648
9649
9650
9651
9652
9653
# File 'lib/aws-sdk-gamelift/types.rb', line 9646

class PlayerConnectionDetail < Struct.new(
  :player_id,
  :endpoints,
  :player_gateway_token,
  :expiration)
  SENSITIVE = [:player_id]
  include Aws::Structure
end

#player_idString

A unique identifier for a player associated with this connection.

Returns:

  • (String)


9646
9647
9648
9649
9650
9651
9652
9653
# File 'lib/aws-sdk-gamelift/types.rb', line 9646

class PlayerConnectionDetail < Struct.new(
  :player_id,
  :endpoints,
  :player_gateway_token,
  :expiration)
  SENSITIVE = [:player_id]
  include Aws::Structure
end