Class: Aws::GameLift::Types::PlayerConnectionEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Network address(es) and port(s) for connecting to a game session.

Constant Summary collapse

SENSITIVE =
[:ip_address, :port]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_addressString

IP address for connecting to the game session. When player gateway is enabled, this is a player gateway IP address. When player gateway is disabled, this is the game server IP address.

Returns:

  • (String)


9671
9672
9673
9674
9675
9676
# File 'lib/aws-sdk-gamelift/types.rb', line 9671

class PlayerConnectionEndpoint < Struct.new(
  :ip_address,
  :port)
  SENSITIVE = [:ip_address, :port]
  include Aws::Structure
end

#portInteger

Port number for connecting to the game session. When player gateway is enabled, this is a player gateway port. When player gateway is disabled, this is the game server port.

Returns:

  • (Integer)


9671
9672
9673
9674
9675
9676
# File 'lib/aws-sdk-gamelift/types.rb', line 9671

class PlayerConnectionEndpoint < Struct.new(
  :ip_address,
  :port)
  SENSITIVE = [:ip_address, :port]
  include Aws::Structure
end