Class: Aws::GameLift::Types::PlayerGatewayConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Configuration settings for player gateway. Use these settings to specify advanced options for how player gateway handles connections.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_server_ip_protocol_supportedString

The IP protocol that your game servers support for player connections through player gateway. If the value is set to IPv4, GameLift will install and execute a lightweight IP translation software on fleet instances to receive and transform incoming IPv6 traffic to IPv4. If the value is set to DUAL_STACK, the lightweight IP translation software will not be installed on fleet instances. DUAL_STACK provides slightly better performance than IPv4.

Returns:

  • (String)


9694
9695
9696
9697
9698
# File 'lib/aws-sdk-gamelift/types.rb', line 9694

class PlayerGatewayConfiguration < Struct.new(
  :game_server_ip_protocol_supported)
  SENSITIVE = []
  include Aws::Structure
end