Class: Aws::GameLift::Types::PlayerSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::PlayerSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Represents a player session. Player sessions are created either for a specific game session, or as part of a game session placement or matchmaking request. A player session can represents a reserved player slot in a game session (when status is ‘RESERVED`) or actual player activity in a game session (when status is `ACTIVE`). A player session object, including player data, is automatically passed to a game session when the player connects to the game session and is validated. After the game session ends, player sessions information is retained for 30 days and then removed.
**Related actions**
Constant Summary collapse
- SENSITIVE =
[:player_id, :ip_address, :port]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
A time stamp indicating when this data object was created.
-
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session.
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) associated with the GameLift fleet that the player’s game session is running on.
-
#fleet_id ⇒ String
A unique identifier for the fleet that the player’s game session is running on.
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions that the player session is connected to.
-
#ip_address ⇒ String
The IP address of the game session.
-
#player_data ⇒ String
Developer-defined information related to a player.
-
#player_id ⇒ String
A unique identifier for a player that is associated with this player session.
-
#player_session_id ⇒ String
A unique identifier for a player session.
-
#port ⇒ Integer
Port number for the game session.
-
#status ⇒ String
Current status of the player session.
-
#termination_time ⇒ Time
A time stamp indicating when this data object was terminated.
Instance Attribute Details
#creation_time ⇒ Time
A time stamp indicating when this data object was created. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#dns_name ⇒ String
The DNS identifier assigned to the instance that is running the game session. Values have the following format:
-
TLS-enabled fleets: ‘<unique identifier>.<region identifier>.amazongamelift.com`.
-
Non-TLS-enabled fleets: ‘ec2-<unique identifier>.compute.amazonaws.com`. (See [Amazon EC2 Instance IP Addressing].)
When connecting to a game session that is running on a TLS-enabled fleet, you must use the DNS name, not the IP address.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#concepts-public-addresses
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) associated with the GameLift fleet that the player’s game session is running on.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that the player’s game session is running on.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions that the player session is connected to. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#player_data ⇒ String
Developer-defined information related to a player. Amazon GameLift Servers does not use this data, so it can be formatted as needed for use in the game.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#player_id ⇒ String
A unique identifier for a player that is associated with this player session.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#player_session_id ⇒ String
A unique identifier for a player session.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#port ⇒ Integer
Port number for the game session. To connect to a Amazon GameLift Servers server process, an app needs both the IP address and port number.
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#status ⇒ String
Current status of the player session.
Possible player session statuses include the following:
-
RESERVED – The player session request has been received, but the player has not yet connected to the server process and/or been validated.
-
ACTIVE – The player has been validated by the server process and is currently connected.
-
COMPLETED – The player connection has been dropped.
-
TIMEDOUT – A player session request was received, but the player did not connect and/or was not validated within the timeout limit (60 seconds).
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |
#termination_time ⇒ Time
A time stamp indicating when this data object was terminated. Format is a number expressed in Unix time as milliseconds (for example ‘“1469498468.057”`).
10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10137 class PlayerSession < Struct.new( :player_session_id, :player_id, :game_session_id, :fleet_id, :fleet_arn, :creation_time, :termination_time, :status, :ip_address, :dns_name, :port, :player_data) SENSITIVE = [:player_id, :ip_address, :port] include Aws::Structure end |