Class: Aws::GameLift::Types::SearchGameSessionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::SearchGameSessionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_sessions ⇒ Array<Types::GameSession>
A collection of objects containing game session properties for each session that matches the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_sessions ⇒ Array<Types::GameSession>
A collection of objects containing game session properties for each session that matches the request.
11349 11350 11351 11352 11353 11354 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11349 class SearchGameSessionsOutput < Struct.new( :game_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
11349 11350 11351 11352 11353 11354 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11349 class SearchGameSessionsOutput < Struct.new( :game_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |