Class: Aws::GameLift::Types::ServerProcess
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ServerProcess
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
A set of instructions for launching server processes on fleet computes. Server processes run either an executable in a custom game build or a Amazon GameLift Servers Realtime script. Server process configurations are part of a fleet’s runtime configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#concurrent_executions ⇒ Integer
The number of server processes using this configuration that run concurrently on each instance or compute.
-
#launch_path ⇒ String
The location of a game build executable or Realtime script.
-
#parameters ⇒ String
An optional list of parameters to pass to the server executable or Realtime script on launch.
Instance Attribute Details
#concurrent_executions ⇒ Integer
The number of server processes using this configuration that run concurrently on each instance or compute.
10946 10947 10948 10949 10950 10951 10952 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10946 class ServerProcess < Struct.new( :launch_path, :parameters, :concurrent_executions) SENSITIVE = [] include Aws::Structure end |
#launch_path ⇒ String
The location of a game build executable or Realtime script. Game builds and Realtime scripts are installed on instances at the root:
-
Windows (custom game builds only): ‘C:game`. Example: “`C:gameMyGameserver.exe`”
-
Linux:
/local/game. Examples: “/local/game/MyGame/server.exe” or “/local/game/MyRealtimeScript.js”
<note markdown=“1”> Amazon GameLift Servers doesn’t support the use of setup scripts that launch the game executable. For custom game builds, this parameter must indicate the executable that calls the server SDK operations ‘initSDK()` and `ProcessReady()`.
</note>
10946 10947 10948 10949 10950 10951 10952 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10946 class ServerProcess < Struct.new( :launch_path, :parameters, :concurrent_executions) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ String
An optional list of parameters to pass to the server executable or Realtime script on launch.
10946 10947 10948 10949 10950 10951 10952 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10946 class ServerProcess < Struct.new( :launch_path, :parameters, :concurrent_executions) SENSITIVE = [] include Aws::Structure end |