Class: Aws::GameLift::Types::StartGameSessionPlacementInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_player_sessionsArray<Types::DesiredPlayerSession>

Set of information on each player to create a player session for.

Returns:



11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#game_propertiesArray<Types::GameProperty>

A set of key-value pairs that can store custom data in a game session. For example: ‘“difficulty”, “Value”: “novice”`.

<note markdown=“1”> * Avoid using periods (“.”) in property keys if you plan to search

for game sessions by properties. Property keys containing periods
cannot be searched and will be filtered out from search results
due to search index limitations.
  • If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.

</note>

Returns:



11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#game_session_dataString

A set of custom game session properties, formatted as a single string value. This data is passed to a game server process with a request to start a new game session. For more information, see [Start a game session].

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-server-api.html#gamelift-sdk-server-startsession

Returns:

  • (String)


11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#game_session_nameString

A descriptive label that is associated with a game session. Session names do not need to be unique.

Returns:

  • (String)


11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#game_session_queue_nameString

Name of the queue to use to place the new game session. You can use either the queue name or ARN value.

Returns:

  • (String)


11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_player_session_countInteger

The maximum number of players that can be connected simultaneously to the game session.

Returns:

  • (Integer)


11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#placement_idString

A unique identifier to assign to the new game session placement. This value is developer-defined. The value must be unique across all Regions and cannot be reused.

Returns:

  • (String)


11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#player_latenciesArray<Types::PlayerLatency>

A set of values, expressed in milliseconds, that indicates the amount of latency that a player experiences when connected to Amazon Web Services Regions. This information is used to try to place the new game session where it can offer the best possible gameplay experience for the players.

Returns:



11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end

#priority_configuration_overrideTypes::PriorityConfigurationOverride

A prioritized list of locations to use for the game session placement and instructions on how to use it. This list overrides a queue’s prioritized location list for this game session placement request only. You can include Amazon Web Services Regions, local zones, and custom locations (for Anywhere fleets). You can choose to limit placements to locations on the override list only, or you can prioritize locations on the override list first and then fall back to the queue’s other locations if needed. Choose a fallback strategy to use in the event that Amazon GameLift Servers fails to place a game session in any of the locations on the priority override list.



11080
11081
11082
11083
11084
11085
11086
11087
11088
11089
11090
11091
11092
# File 'lib/aws-sdk-gamelift/types.rb', line 11080

class StartGameSessionPlacementInput < Struct.new(
  :placement_id,
  :game_session_queue_name,
  :game_properties,
  :maximum_player_session_count,
  :game_session_name,
  :player_latencies,
  :desired_player_sessions,
  :game_session_data,
  :priority_configuration_override)
  SENSITIVE = []
  include Aws::Structure
end