Class: Aws::GameLift::Types::StartGameSessionPlacementOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_session_placementTypes::GameSessionPlacement

Object that describes the newly created game session placement. This object includes all the information provided in the request, as well as start/end time stamps and placement status.



11377
11378
11379
11380
11381
# File 'lib/aws-sdk-gamelift/types.rb', line 11377

class StartGameSessionPlacementOutput < Struct.new(
  :game_session_placement)
  SENSITIVE = []
  include Aws::Structure
end