Class: Aws::GameLift::Types::StartMatchmakingInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::StartMatchmakingInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_name ⇒ String
Name of the matchmaking configuration to use for this request.
-
#players ⇒ Array<Types::Player>
Information on each player to be matched.
-
#ticket_id ⇒ String
A unique identifier for a matchmaking ticket.
Instance Attribute Details
#configuration_name ⇒ String
Name of the matchmaking configuration to use for this request. Matchmaking configurations must exist in the same Region as this request. You can use either the configuration name or ARN value.
11205 11206 11207 11208 11209 11210 11211 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11205 class StartMatchmakingInput < Struct.new( :ticket_id, :configuration_name, :players) SENSITIVE = [] include Aws::Structure end |
#players ⇒ Array<Types::Player>
Information on each player to be matched. This information must include a player ID, and may contain player attributes and latency data to be used in the matchmaking process. After a successful match, Player objects contain the name of the team the player is assigned to.
You can include up to 10 Players in a StartMatchmaking request.
11205 11206 11207 11208 11209 11210 11211 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11205 class StartMatchmakingInput < Struct.new( :ticket_id, :configuration_name, :players) SENSITIVE = [] include Aws::Structure end |
#ticket_id ⇒ String
A unique identifier for a matchmaking ticket. If no ticket ID is specified here, Amazon GameLift Servers will generate one in the form of a UUID. Use this identifier to track the matchmaking ticket status and retrieve match results.
11205 11206 11207 11208 11209 11210 11211 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11205 class StartMatchmakingInput < Struct.new( :ticket_id, :configuration_name, :players) SENSITIVE = [] include Aws::Structure end |