Class: Aws::GameLift::Types::StartMatchmakingOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matchmaking_ticketTypes::MatchmakingTicket

Ticket representing the matchmaking request. This object include the information included in the request, ticket status, and match results as generated during the matchmaking process.

Returns:



11226
11227
11228
11229
11230
# File 'lib/aws-sdk-gamelift/types.rb', line 11226

class StartMatchmakingOutput < Struct.new(
  :matchmaking_ticket)
  SENSITIVE = []
  include Aws::Structure
end