Class: Aws::GameLift::Types::TargetTrackingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::TargetTrackingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Settings for a target-based scaling policy as part of a
GameServerGroupAutoScalingPolicy . These settings are used to
create a target-based policy that tracks the Amazon GameLift Servers
FleetIQ metric "PercentUtilizedGameServers" and specifies a target
value for the metric. As player usage changes, the policy triggers to
adjust the game server group capacity so that the metric returns to
the target value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#target_value ⇒ Float
Desired value to use with a game server group target-based scaling policy.
Instance Attribute Details
#target_value ⇒ Float
Desired value to use with a game server group target-based scaling policy.
12239 12240 12241 12242 12243 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12239 class TargetTrackingConfiguration < Struct.new( :target_value) SENSITIVE = [] include Aws::Structure end |