Class: Aws::GameLift::Types::TerminalRoutingStrategyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::TerminalRoutingStrategyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
The service is unable to resolve the routing for a particular alias because it has a terminal RoutingStrategy associated with it. The message returned in this exception is the message defined in the routing strategy itself. Such requests should only be retried if the routing strategy for the specified alias is modified.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
11778 11779 11780 11781 11782 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11778 class TerminalRoutingStrategyException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |