Class: Aws::GameLift::Types::TerminateGameSessionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_session_idString

An identifier for the game session that is unique across all regions to be terminated. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.

Returns:

  • (String)


12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-gamelift/types.rb', line 12097

class TerminateGameSessionInput < Struct.new(
  :game_session_id,
  :termination_mode)
  SENSITIVE = []
  include Aws::Structure
end

#termination_modeString

The method to use to terminate the game session. Available methods include:

  • ‘TRIGGER_ON_PROCESS_TERMINATE` – Prompts the Amazon GameLift Servers service to send an `OnProcessTerminate()` callback to the server process and initiate the normal game session shutdown sequence. The `OnProcessTerminate` method, which is implemented in the game server code, must include a call to the server SDK action `ProcessEnding()`, which is how the server process signals to Amazon GameLift Servers that a game session is ending. If the server process doesn’t call ‘ProcessEnding()`, the game session termination won’t conclude successfully.

  • ‘FORCE_TERMINATE` – Prompts the Amazon GameLift Servers service to stop the server process immediately. Amazon GameLift Servers takes action (depending on the type of fleet) to shut down the server process without the normal game session shutdown sequence.

    <note markdown=“1”> This method is not available for game sessions that are running on Anywhere fleets unless the fleet is deployed with the Amazon GameLift Servers Agent. In this scenario, a force terminate request results in an invalid or bad request exception.

    </note>
    

Returns:

  • (String)


12097
12098
12099
12100
12101
12102
# File 'lib/aws-sdk-gamelift/types.rb', line 12097

class TerminateGameSessionInput < Struct.new(
  :game_session_id,
  :termination_mode)
  SENSITIVE = []
  include Aws::Structure
end