Class: Aws::GameLift::Types::TerminateGameSessionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_sessionTypes::GameSession

Properties describing a game session.

A game session in ACTIVE status can host players. When a game session ends, its status is set to TERMINATED.

Amazon GameLift Servers retains a game session resource for 30 days after the game session ends. You can reuse idempotency token values after this time. Game session logs are retained for 14 days.

All APIs by task][1

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html#reference-awssdk-resources-fleets

Returns:



11846
11847
11848
11849
11850
# File 'lib/aws-sdk-gamelift/types.rb', line 11846

class TerminateGameSessionOutput < Struct.new(
  :game_session)
  SENSITIVE = []
  include Aws::Structure
end