Class: Aws::GameLift::Types::UpdateFleetAttributesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateFleetAttributesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_configuration ⇒ Types::AnywhereConfiguration
Amazon GameLift Servers Anywhere configuration options.
-
#description ⇒ String
A human-readable description of a fleet.
-
#fleet_id ⇒ String
A unique identifier for the fleet to update attribute metadata for.
-
#metric_groups ⇒ Array<String>
The name of a metric group to add this fleet to.
-
#name ⇒ String
A descriptive label that is associated with a fleet.
-
#new_game_session_protection_policy ⇒ String
The game session protection policy to apply to all new game sessions created in this fleet.
-
#resource_creation_limit_policy ⇒ Types::ResourceCreationLimitPolicy
Policy settings that limit the number of game sessions an individual player can create over a span of time.
Instance Attribute Details
#anywhere_configuration ⇒ Types::AnywhereConfiguration
Amazon GameLift Servers Anywhere configuration options.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable description of a fleet.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet to update attribute metadata for. You can use either the fleet ID or ARN value.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#metric_groups ⇒ Array<String>
The name of a metric group to add this fleet to. Use a metric group in Amazon CloudWatch to aggregate the metrics from multiple fleets. Provide an existing metric group name, or create a new metric group by providing a new name. A fleet can only be in one metric group at a time.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive label that is associated with a fleet. Fleet names do not need to be unique.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#new_game_session_protection_policy ⇒ String
The game session protection policy to apply to all new game sessions created in this fleet. Game sessions that already exist are not affected. You can set protection for individual game sessions using
- UpdateGameSession][1
-
.
-
NoProtection – The game session can be terminated during a scale-down event.
-
FullProtection – If the game session is in an
ACTIVEstatus, it cannot be terminated during a scale-down event.
[1]: docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSession.html
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |
#resource_creation_limit_policy ⇒ Types::ResourceCreationLimitPolicy
Policy settings that limit the number of game sessions an individual player can create over a span of time.
12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12291 class UpdateFleetAttributesInput < Struct.new( :fleet_id, :name, :description, :new_game_session_protection_policy, :resource_creation_limit_policy, :metric_groups, :anywhere_configuration) SENSITIVE = [] include Aws::Structure end |