Class: Aws::GameLift::Types::UpdateGameSessionQueueInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateGameSessionQueueInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_event_data ⇒ String
Information to be added to all events that are related to this game session queue.
-
#destinations ⇒ Array<Types::GameSessionQueueDestination>
A list of fleets and/or fleet aliases that can be used to fulfill game session placement requests in the queue.
-
#filter_configuration ⇒ Types::FilterConfiguration
A list of locations where a queue is allowed to place new game sessions.
-
#name ⇒ String
A descriptive label that is associated with game session queue.
-
#notification_target ⇒ String
An SNS topic ARN that is set up to receive game session placement notifications.
-
#player_latency_policies ⇒ Array<Types::PlayerLatencyPolicy>
A set of policies that enforce a sliding cap on player latency when processing game sessions placement requests.
-
#priority_configuration ⇒ Types::PriorityConfiguration
Custom settings to use when prioritizing destinations and locations for game session placements.
-
#timeout_in_seconds ⇒ Integer
The maximum time, in seconds, that a new game session placement request remains in the queue.
Instance Attribute Details
#custom_event_data ⇒ String
Information to be added to all events that are related to this game session queue.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::GameSessionQueueDestination>
A list of fleets and/or fleet aliases that can be used to fulfill game session placement requests in the queue. Destinations are identified by either a fleet ARN or a fleet alias ARN, and are listed in order of placement preference. When updating this list, provide a complete list of destinations.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#filter_configuration ⇒ Types::FilterConfiguration
A list of locations where a queue is allowed to place new game sessions. Locations are specified in the form of Amazon Web Services Region codes, such as us-west-2. If this parameter is not set, game sessions can be placed in any queue location. To remove an existing filter configuration, pass in an empty set.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive label that is associated with game session queue. Queue names must be unique within each Region. You can use either the queue ID or ARN value.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#notification_target ⇒ String
An SNS topic ARN that is set up to receive game session placement notifications. See [ Setting up notifications for game session placement].
[1]: docs.aws.amazon.com/gamelift/latest/developerguide/queue-notification.html
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#player_latency_policies ⇒ Array<Types::PlayerLatencyPolicy>
A set of policies that enforce a sliding cap on player latency when processing game sessions placement requests. Use multiple policies to gradually relax the cap over time if Amazon GameLift Servers can’t make a placement. Policies are evaluated in order starting with the lowest maximum latency value. When updating policies, provide a complete collection of policies.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#priority_configuration ⇒ Types::PriorityConfiguration
Custom settings to use when prioritizing destinations and locations for game session placements. This configuration replaces the FleetIQ default prioritization process. Priority types that are not explicitly named will be automatically applied at the end of the prioritization process. To remove an existing priority configuration, pass in an empty set.
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |
#timeout_in_seconds ⇒ Integer
The maximum time, in seconds, that a new game session placement request remains in the queue. When a request exceeds this time, the game session placement changes to a TIMED_OUT status.
<note markdown=“1”> The minimum value is 10 and the maximum value is 600.
</note>
12754 12755 12756 12757 12758 12759 12760 12761 12762 12763 12764 12765 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12754 class UpdateGameSessionQueueInput < Struct.new( :name, :timeout_in_seconds, :player_latency_policies, :destinations, :filter_configuration, :priority_configuration, :custom_event_data, :notification_target) SENSITIVE = [] include Aws::Structure end |