Class: Aws::GameLift::Types::UpdateRuntimeConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_idString

A unique identifier for the fleet to update runtime configuration for. You can use either the fleet ID or ARN value.

Returns:



12966
12967
12968
12969
12970
12971
# File 'lib/aws-sdk-gamelift/types.rb', line 12966

class UpdateRuntimeConfigurationInput < Struct.new(
  :fleet_id,
  :runtime_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_configurationTypes::RuntimeConfiguration

Instructions for launching server processes on fleet computes. Server processes run either a custom game build executable or a Amazon GameLift Servers Realtime script. The runtime configuration lists the types of server processes to run, how to launch them, and the number of processes to run concurrently.

Returns:



12966
12967
12968
12969
12970
12971
# File 'lib/aws-sdk-gamelift/types.rb', line 12966

class UpdateRuntimeConfigurationInput < Struct.new(
  :fleet_id,
  :runtime_configuration)
  SENSITIVE = []
  include Aws::Structure
end