Class: Aws::GameLift::Types::ConnectionPortRange
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ConnectionPortRange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
The set of port numbers to open on each instance in a container fleet. Connection ports are used by inbound traffic to connect with processes that are running in containers on the fleet.
The port range must not overlap with the Amazon GameLift Servers reserved port range ‘4092-4191`. This range is reserved for internal Amazon GameLift Servers services.
Constant Summary collapse
- SENSITIVE =
[:from_port, :to_port]
Instance Attribute Summary collapse
-
#from_port ⇒ Integer
Starting value for the port range.
-
#to_port ⇒ Integer
Ending value for the port.
Instance Attribute Details
#from_port ⇒ Integer
Starting value for the port range.
584 585 586 587 588 589 |
# File 'lib/aws-sdk-gamelift/types.rb', line 584 class ConnectionPortRange < Struct.new( :from_port, :to_port) SENSITIVE = [:from_port, :to_port] include Aws::Structure end |
#to_port ⇒ Integer
Ending value for the port. Port numbers are end-inclusive. This value must be equal to or greater than ‘FromPort`.
584 585 586 587 588 589 |
# File 'lib/aws-sdk-gamelift/types.rb', line 584 class ConnectionPortRange < Struct.new( :from_port, :to_port) SENSITIVE = [:from_port, :to_port] include Aws::Structure end |