Class: Aws::GameLift::Types::ContainerGroupPortMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Describes the port mappings for a single container in a container group. Each mapping shows how a container port maps to a connection port on the fleet instance.

Returned by: DescribeContainerGroupPortMappings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_nameString

The name of the container, as defined in the container group definition.

Returns:

  • (String)


1197
1198
1199
1200
1201
1202
1203
# File 'lib/aws-sdk-gamelift/types.rb', line 1197

class ContainerGroupPortMapping < Struct.new(
  :container_name,
  :container_runtime_id,
  :container_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#container_port_mappingsArray<Types::ContainerPortMapping>

A list of ContainerPortMapping objects that describe the port mappings for this container.

Returns:



1197
1198
1199
1200
1201
1202
1203
# File 'lib/aws-sdk-gamelift/types.rb', line 1197

class ContainerGroupPortMapping < Struct.new(
  :container_name,
  :container_runtime_id,
  :container_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#container_runtime_idString

The runtime ID for the container that's running in a compute. This value is unique within the compute.

Returns:

  • (String)


1197
1198
1199
1200
1201
1202
1203
# File 'lib/aws-sdk-gamelift/types.rb', line 1197

class ContainerGroupPortMapping < Struct.new(
  :container_name,
  :container_runtime_id,
  :container_port_mappings)
  SENSITIVE = []
  include Aws::Structure
end