Class: Aws::GameLift::Types::CreateFleetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::CreateFleetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_attributes ⇒ Types::FleetAttributes
The properties for the new fleet, including the current status.
-
#location_states ⇒ Array<Types::LocationState>
The fleet’s locations and life-cycle status of each location.
Instance Attribute Details
#fleet_attributes ⇒ Types::FleetAttributes
The properties for the new fleet, including the current status. All fleets are placed in ‘NEW` status on creation.
2485 2486 2487 2488 2489 2490 |
# File 'lib/aws-sdk-gamelift/types.rb', line 2485 class CreateFleetOutput < Struct.new( :fleet_attributes, :location_states) SENSITIVE = [] include Aws::Structure end |
#location_states ⇒ Array<Types::LocationState>
The fleet’s locations and life-cycle status of each location. For new fleets, the status of all locations is set to ‘NEW`. During fleet creation, Amazon GameLift Servers updates each location status as instances are deployed there and prepared for game hosting. This list includes an entry for the fleet’s home Region. For fleets with no remote locations, only one entry, representing the home Region, is returned.
2485 2486 2487 2488 2489 2490 |
# File 'lib/aws-sdk-gamelift/types.rb', line 2485 class CreateFleetOutput < Struct.new( :fleet_attributes, :location_states) SENSITIVE = [] include Aws::Structure end |