Class: Aws::GameLift::Types::CreateVpcPeeringConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_idString

A unique identifier for the fleet. You can use either the fleet ID or ARN value. This tells Amazon GameLift Servers which GameLift VPC to peer with.

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-gamelift/types.rb', line 3444

class CreateVpcPeeringConnectionInput < Struct.new(
  :fleet_id,
  :peer_vpc_aws_account_id,
  :peer_vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_vpc_aws_account_idString

A unique identifier for the Amazon Web Services account with the VPC that you want to peer your Amazon GameLift Servers fleet with. You can find your Account ID in the Amazon Web Services Management Console under account settings.

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-gamelift/types.rb', line 3444

class CreateVpcPeeringConnectionInput < Struct.new(
  :fleet_id,
  :peer_vpc_aws_account_id,
  :peer_vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_vpc_idString

A unique identifier for a VPC with resources to be accessed by your Amazon GameLift Servers fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the [VPC Dashboard] in the Amazon Web Services Management Console. Learn more about VPC peering in [VPC Peering with Amazon GameLift Servers Fleets].

[1]: console.aws.amazon.com/vpc/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/vpc-peering.html

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
# File 'lib/aws-sdk-gamelift/types.rb', line 3444

class CreateVpcPeeringConnectionInput < Struct.new(
  :fleet_id,
  :peer_vpc_aws_account_id,
  :peer_vpc_id)
  SENSITIVE = []
  include Aws::Structure
end