Class: Aws::GameLift::Types::DeleteMatchmakingRuleSetInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DeleteMatchmakingRuleSetInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
A unique identifier for the matchmaking rule set to be deleted.
Instance Attribute Details
#name ⇒ String
A unique identifier for the matchmaking rule set to be deleted. (Note: The rule set name is different from the optional “name” field in the rule set body.) You can use either the rule set name or ARN value.
3692 3693 3694 3695 3696 |
# File 'lib/aws-sdk-gamelift/types.rb', line 3692 class DeleteMatchmakingRuleSetInput < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |