Class: Aws::GameLift::Types::DeleteVpcPeeringAuthorizationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#game_lift_aws_account_idString

A unique identifier for the Amazon Web Services account that you use to manage your Amazon GameLift Servers fleet. You can find your Account ID in the Amazon Web Services Management Console under account settings.

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
# File 'lib/aws-sdk-gamelift/types.rb', line 3661

class DeleteVpcPeeringAuthorizationInput < Struct.new(
  :game_lift_aws_account_id,
  :peer_vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#peer_vpc_idString

A unique identifier for a VPC with resources to be accessed by your Amazon GameLift Servers fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the [VPC Dashboard] in the Amazon Web Services Management Console. Learn more about VPC peering in [VPC Peering with Amazon GameLift Servers Fleets].

[1]: console.aws.amazon.com/vpc/ [2]: docs.aws.amazon.com/gamelift/latest/developerguide/vpc-peering.html

Returns:

  • (String)


3661
3662
3663
3664
3665
3666
# File 'lib/aws-sdk-gamelift/types.rb', line 3661

class DeleteVpcPeeringAuthorizationInput < Struct.new(
  :game_lift_aws_account_id,
  :peer_vpc_id)
  SENSITIVE = []
  include Aws::Structure
end