Class: Aws::GameLift::Types::DescribeContainerGroupPortMappingsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeContainerGroupPortMappingsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_name ⇒ String
A unique identifier for the compute resource for which to retrieve port mappings.
-
#container_group_type ⇒ String
The type of container group to retrieve port mappings for.
-
#container_name ⇒ String
A container name to filter the results.
-
#fleet_id ⇒ String
A unique identifier for the container fleet.
-
#instance_id ⇒ String
A unique identifier for the fleet instance to retrieve port mappings for.
Instance Attribute Details
#compute_name ⇒ String
A unique identifier for the compute resource for which to retrieve port mappings. For a container fleet, a compute represents a game server container group running on a fleet instance. You can use either the compute name or ARN value.
When ‘ContainerGroupType` is `GAME_SERVER`, this parameter is required.
When ‘ContainerGroupType` is `PER_INSTANCE`, do not provide this parameter. If you provide a compute name with `PER_INSTANCE`, the request fails with an `InvalidRequestException`.
4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4079 class DescribeContainerGroupPortMappingsInput < Struct.new( :fleet_id, :container_group_type, :compute_name, :instance_id, :container_name) SENSITIVE = [] include Aws::Structure end |
#container_group_type ⇒ String
The type of container group to retrieve port mappings for.
-
‘GAME_SERVER` – Get port mappings for a game server container group.
-
‘PER_INSTANCE` – Get port mappings for a per-instance container group.
4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4079 class DescribeContainerGroupPortMappingsInput < Struct.new( :fleet_id, :container_group_type, :compute_name, :instance_id, :container_name) SENSITIVE = [] include Aws::Structure end |
#container_name ⇒ String
A container name to filter the results. When provided, the operation returns port mappings for the specified container only. If no container with the specified name exists in the container group, the request fails with a ‘NotFoundException`.
If not provided, the operation returns port mappings for all containers in the container group.
4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4079 class DescribeContainerGroupPortMappingsInput < Struct.new( :fleet_id, :container_group_type, :compute_name, :instance_id, :container_name) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the container fleet. You can use either the fleet ID or ARN value.
4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4079 class DescribeContainerGroupPortMappingsInput < Struct.new( :fleet_id, :container_group_type, :compute_name, :instance_id, :container_name) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
A unique identifier for the fleet instance to retrieve port mappings for.
When ‘ContainerGroupType` is `PER_INSTANCE`, this parameter is required.
When ‘ContainerGroupType` is `GAME_SERVER`, this parameter is optional. If you provide an instance ID, it must match the instance that’s running the specified compute. If the instance ID doesn’t match, the request fails with an ‘InvalidRequestException`.
4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4079 class DescribeContainerGroupPortMappingsInput < Struct.new( :fleet_id, :container_group_type, :compute_name, :instance_id, :container_name) SENSITIVE = [] include Aws::Structure end |