Class: Aws::GameLift::Types::DescribeContainerGroupPortMappingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeContainerGroupPortMappingsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_name ⇒ String
A unique identifier for the compute resource running the game server container group.
-
#container_group_definition_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to the container group definition.
-
#container_group_port_mappings ⇒ Array<Types::ContainerGroupPortMapping>
A list of ‘ContainerGroupPortMapping` objects that describe the port mappings for each container in the container group.
-
#container_group_type ⇒ String
The type of container group that was specified in the request.
-
#fleet_id ⇒ String
A unique identifier for the container fleet.
-
#instance_id ⇒ String
A unique identifier for the fleet instance.
-
#location ⇒ String
The location of the fleet instance, expressed as an Amazon Web Services Region code, such as ‘us-west-2`.
Instance Attribute Details
#compute_name ⇒ String
A unique identifier for the compute resource running the game server container group. Returned when ‘ContainerGroupType` is `GAME_SERVER`.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#container_group_definition_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to the container group definition. The ARN value also identifies the specific container group definition version in use.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#container_group_port_mappings ⇒ Array<Types::ContainerGroupPortMapping>
A list of ‘ContainerGroupPortMapping` objects that describe the port mappings for each container in the container group.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#container_group_type ⇒ String
The type of container group that was specified in the request. Valid values are ‘GAME_SERVER` or `PER_INSTANCE`.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the container fleet.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
A unique identifier for the fleet instance. For ‘GAME_SERVER` requests, this is the instance running the specified compute. For `PER_INSTANCE` requests, this is the instance specified in the request.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location of the fleet instance, expressed as an Amazon Web Services Region code, such as ‘us-west-2`.
4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4133 class DescribeContainerGroupPortMappingsOutput < Struct.new( :fleet_id, :location, :container_group_definition_arn, :container_group_type, :compute_name, :instance_id, :container_group_port_mappings) SENSITIVE = [] include Aws::Structure end |