Class: Aws::GameLift::Types::DescribeFleetAttributesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetAttributesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_attributes ⇒ Array<Types::FleetAttributes>
A collection of objects containing attribute metadata for each requested fleet ID.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#fleet_attributes ⇒ Array<Types::FleetAttributes>
A collection of objects containing attribute metadata for each requested fleet ID. Attribute objects are returned only for fleets that currently exist.
4224 4225 4226 4227 4228 4229 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4224 class DescribeFleetAttributesOutput < Struct.new( :fleet_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4224 4225 4226 4227 4228 4229 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4224 class DescribeFleetAttributesOutput < Struct.new( :fleet_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |