Class: Aws::GameLift::Types::DescribeFleetEventsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetEventsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:events]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
A collection of objects containing event log entries for the specified fleet.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#events ⇒ Array<Types::Event>
A collection of objects containing event log entries for the specified fleet.
4404 4405 4406 4407 4408 4409 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4404 class DescribeFleetEventsOutput < Struct.new( :events, :next_token) SENSITIVE = [:events] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4404 4405 4406 4407 4408 4409 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4404 class DescribeFleetEventsOutput < Struct.new( :events, :next_token) SENSITIVE = [:events] include Aws::Structure end |