Class: Aws::GameLift::Types::DescribeFleetEventsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetEventsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
A collection of objects containing event log entries for the specified fleet.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#events ⇒ Array<Types::Event>
A collection of objects containing event log entries for the specified fleet.
4150 4151 4152 4153 4154 4155 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4150 class DescribeFleetEventsOutput < Struct.new( :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4150 4151 4152 4153 4154 4155 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4150 class DescribeFleetEventsOutput < Struct.new( :events, :next_token) SENSITIVE = [] include Aws::Structure end |