Class: Aws::GameLift::Types::DescribeFleetLocationAttributesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetLocationAttributesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it.
-
#fleet_id ⇒ String
A unique identifier for the fleet that location attributes were requested for.
-
#location_attributes ⇒ Array<Types::LocationAttributes>
Location-specific information on the requested fleet’s remote locations.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#fleet_arn ⇒ String
The Amazon Resource Name ([ARN]) that is assigned to a Amazon GameLift Servers fleet resource and uniquely identifies it. ARNs are unique across all Regions. Format is ‘arn:aws:gamelift:<region>::fleet/fleet-a1234567-b8c9-0d1e-2fa3-b45c6d7e8912`.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/s3-arn-format.html
4221 4222 4223 4224 4225 4226 4227 4228 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4221 class DescribeFleetLocationAttributesOutput < Struct.new( :fleet_id, :fleet_arn, :location_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet that location attributes were requested for.
4221 4222 4223 4224 4225 4226 4227 4228 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4221 class DescribeFleetLocationAttributesOutput < Struct.new( :fleet_id, :fleet_arn, :location_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |
#location_attributes ⇒ Array<Types::LocationAttributes>
Location-specific information on the requested fleet’s remote locations.
4221 4222 4223 4224 4225 4226 4227 4228 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4221 class DescribeFleetLocationAttributesOutput < Struct.new( :fleet_id, :fleet_arn, :location_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4221 4222 4223 4224 4225 4226 4227 4228 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4221 class DescribeFleetLocationAttributesOutput < Struct.new( :fleet_id, :fleet_arn, :location_attributes, :next_token) SENSITIVE = [] include Aws::Structure end |