Class: Aws::GameLift::Types::DescribeFleetUtilizationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeFleetUtilizationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_utilization ⇒ Array<Types::FleetUtilization>
A collection of objects containing utilization information for each requested fleet ID.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#fleet_utilization ⇒ Array<Types::FleetUtilization>
A collection of objects containing utilization information for each requested fleet ID. Utilization objects are returned only for fleets that currently exist.
4660 4661 4662 4663 4664 4665 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4660 class DescribeFleetUtilizationOutput < Struct.new( :fleet_utilization, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4660 4661 4662 4663 4664 4665 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4660 class DescribeFleetUtilizationOutput < Struct.new( :fleet_utilization, :next_token) SENSITIVE = [] include Aws::Structure end |