Class: Aws::GameLift::Types::DescribeGameServerInstancesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameServerInstancesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_server_instances ⇒ Array<Types::GameServerInstance>
The collection of requested game server instances.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_server_instances ⇒ Array<Types::GameServerInstance>
The collection of requested game server instances.
4759 4760 4761 4762 4763 4764 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4759 class DescribeGameServerInstancesOutput < Struct.new( :game_server_instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4759 4760 4761 4762 4763 4764 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4759 class DescribeGameServerInstancesOutput < Struct.new( :game_server_instances, :next_token) SENSITIVE = [] include Aws::Structure end |