Class: Aws::GameLift::Types::DescribeGameSessionQueuesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeGameSessionQueuesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session_queues ⇒ Array<Types::GameSessionQueue>
A collection of objects that describe the requested game session queues.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#game_session_queues ⇒ Array<Types::GameSessionQueue>
A collection of objects that describe the requested game session queues.
4923 4924 4925 4926 4927 4928 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4923 class DescribeGameSessionQueuesOutput < Struct.new( :game_session_queues, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4923 4924 4925 4926 4927 4928 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4923 class DescribeGameSessionQueuesOutput < Struct.new( :game_session_queues, :next_token) SENSITIVE = [] include Aws::Structure end |