Class: Aws::GameLift::Types::DescribeInstancesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeInstancesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instances ⇒ Array<Types::Instance>
A collection of objects containing properties for each instance returned.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#instances ⇒ Array<Types::Instance>
A collection of objects containing properties for each instance returned.
5062 5063 5064 5065 5066 5067 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5062 class DescribeInstancesOutput < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5062 5063 5064 5065 5066 5067 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5062 class DescribeInstancesOutput < Struct.new( :instances, :next_token) SENSITIVE = [] include Aws::Structure end |