Class: Aws::GameLift::Types::DescribeMatchmakingConfigurationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeMatchmakingConfigurationsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configurations ⇒ Array<Types::MatchmakingConfiguration>
A collection of requested matchmaking configurations.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#configurations ⇒ Array<Types::MatchmakingConfiguration>
A collection of requested matchmaking configurations.
5117 5118 5119 5120 5121 5122 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5117 class DescribeMatchmakingConfigurationsOutput < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5117 5118 5119 5120 5121 5122 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5117 class DescribeMatchmakingConfigurationsOutput < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |