Class: Aws::GameLift::Types::DescribeMatchmakingConfigurationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeMatchmakingConfigurationsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configurations ⇒ Array<Types::MatchmakingConfiguration>
A collection of requested matchmaking configurations.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#configurations ⇒ Array<Types::MatchmakingConfiguration>
A collection of requested matchmaking configurations.
5111 5112 5113 5114 5115 5116 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5111 class DescribeMatchmakingConfigurationsOutput < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5111 5112 5113 5114 5115 5116 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5111 class DescribeMatchmakingConfigurationsOutput < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |