Class: Aws::GameLift::Types::DescribeMatchmakingRuleSetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeMatchmakingRuleSetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
-
#rule_sets ⇒ Array<Types::MatchmakingRuleSet>
A collection of requested matchmaking rule set objects.
Instance Attribute Details
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
4925 4926 4927 4928 4929 4930 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4925 class DescribeMatchmakingRuleSetsOutput < Struct.new( :rule_sets, :next_token) SENSITIVE = [] include Aws::Structure end |
#rule_sets ⇒ Array<Types::MatchmakingRuleSet>
A collection of requested matchmaking rule set objects.
4925 4926 4927 4928 4929 4930 |
# File 'lib/aws-sdk-gamelift/types.rb', line 4925 class DescribeMatchmakingRuleSetsOutput < Struct.new( :rule_sets, :next_token) SENSITIVE = [] include Aws::Structure end |