Class: Aws::GameLift::Types::DescribeScalingPoliciesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::DescribeScalingPoliciesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
-
#scaling_policies ⇒ Array<Types::ScalingPolicy>
A collection of objects containing the scaling policies matching the request.
Instance Attribute Details
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
5374 5375 5376 5377 5378 5379 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5374 class DescribeScalingPoliciesOutput < Struct.new( :scaling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#scaling_policies ⇒ Array<Types::ScalingPolicy>
A collection of objects containing the scaling policies matching the request.
5374 5375 5376 5377 5378 5379 |
# File 'lib/aws-sdk-gamelift/types.rb', line 5374 class DescribeScalingPoliciesOutput < Struct.new( :scaling_policies, :next_token) SENSITIVE = [] include Aws::Structure end |