Class: Aws::GameLift::Types::GameProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GameProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
This key-value pair can store custom data about a game session. For example, you might use a GameProperty to track a game session’s map, level of difficulty, or remaining time. The difficulty level could be specified like this: ‘“difficulty”, “Value”:“Novice”`.
You can set game properties when creating a game session. You can also modify game properties of an active game session. When searching for game sessions, you can filter on game property keys and values. You can’t delete game properties from a game session.
For examples of working with game properties, see [Create a game session with properties].
[1]: docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-sdk-client-api.html#game-properties
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The game property identifier.
-
#value ⇒ String
The game property value.
Instance Attribute Details
#key ⇒ String
The game property identifier.
<note markdown=“1”> * Avoid using periods (“.”) in property keys if you plan to search
for game sessions by properties. Property keys containing periods
cannot be searched and will be filtered out from search results
due to search index limitations.
-
If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.
</note>
6162 6163 6164 6165 6166 6167 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6162 class GameProperty < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The game property value.
6162 6163 6164 6165 6166 6167 |
# File 'lib/aws-sdk-gamelift/types.rb', line 6162 class GameProperty < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |