Class: Aws::GameLift::Types::GameSessionConnectionInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Connection information for a new game session that is created in response to a start matchmaking request. Once a match is made, the FlexMatch engine creates a new game session for it. This information, including the game session endpoint and player sessions for each player in the original matchmaking request, is added to the matchmaking ticket.

Constant Summary collapse

SENSITIVE =
[:ip_address]

Instance Attribute Summary collapse

Instance Attribute Details

#dns_nameString

The DNS identifier assigned to the instance that is running the game session. Values have the following format:

  • TLS-enabled fleets: ‘<unique identifier>.<region identifier>.amazongamelift.com`.

  • Non-TLS-enabled fleets: ‘ec2-<unique identifier>.compute.amazonaws.com`. (See [Amazon EC2 Instance IP Addressing].)

When connecting to a game session that is running on a TLS-enabled fleet, you must use the DNS name, not the IP address.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-instance-addressing.html#concepts-public-addresses

Returns:

  • (String)


7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#game_session_arnString

An identifier for the game session that is unique across all regions. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.

Returns:

  • (String)


7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#ip_addressString

The IP address of the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.

Returns:

  • (String)


7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#matched_player_sessionsArray<Types::MatchedPlayerSession>

A collection of player session IDs, one for each player ID that was included in the original matchmaking request.

Returns:



7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#player_gateway_statusString

The current status of player gateway for the game session. Note, even if a fleet has PlayerGatewayMode configured as ‘ENABLED`, player gateway might not be available in a specific location. For more information about locations where player gateway is supported, see [supported locations].

Possible values include:

  • ‘ENABLED` – Player gateway is available for this game session.

  • ‘DISABLED` – Player gateway is not available for this game session.

[1]: docs.aws.amazon.com/gameliftservers/latest/developerguide/gamelift-regions.html

Returns:

  • (String)


7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end

#portInteger

The port number for the game session. To connect to a Amazon GameLift Servers game server, an app needs both the IP address and port number.

Returns:

  • (Integer)


7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
# File 'lib/aws-sdk-gamelift/types.rb', line 7273

class GameSessionConnectionInfo < Struct.new(
  :game_session_arn,
  :ip_address,
  :dns_name,
  :port,
  :matched_player_sessions,
  :player_gateway_status)
  SENSITIVE = [:ip_address]
  include Aws::Structure
end