Class: Aws::GameLift::Types::GetComputeAuthTokenInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_nameString

The name of the compute resource you are requesting the authentication token for. For an Anywhere fleet compute, use the registered compute name. For an EC2 fleet instance, use the instance ID.

Returns:

  • (String)


7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-gamelift/types.rb', line 7807

class GetComputeAuthTokenInput < Struct.new(
  :fleet_id,
  :compute_name)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the fleet that the compute is registered to.

Returns:

  • (String)


7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-gamelift/types.rb', line 7807

class GetComputeAuthTokenInput < Struct.new(
  :fleet_id,
  :compute_name)
  SENSITIVE = []
  include Aws::Structure
end