Class: Aws::GameLift::Types::GetGameSessionLogUrlInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetGameSessionLogUrlInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to get logs for.
Instance Attribute Details
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to get logs for. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
7876 7877 7878 7879 7880 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7876 class GetGameSessionLogUrlInput < Struct.new( :game_session_id) SENSITIVE = [] include Aws::Structure end |