Class: Aws::GameLift::Types::GetPlayerConnectionDetailsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::GetPlayerConnectionDetailsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions for which the player connection details were retrieved.
-
#player_connection_details ⇒ Array<Types::PlayerConnectionDetail>
A collection of player connection detail objects, one for each requested player.
Instance Attribute Details
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions for which the player connection details were retrieved. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
7971 7972 7973 7974 7975 7976 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7971 class GetPlayerConnectionDetailsOutput < Struct.new( :game_session_id, :player_connection_details) SENSITIVE = [] include Aws::Structure end |
#player_connection_details ⇒ Array<Types::PlayerConnectionDetail>
A collection of player connection detail objects, one for each requested player.
7971 7972 7973 7974 7975 7976 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7971 class GetPlayerConnectionDetailsOutput < Struct.new( :game_session_id, :player_connection_details) SENSITIVE = [] include Aws::Structure end |