Class: Aws::GameLift::Types::ListBuildsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListBuildsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#builds ⇒ Array<Types::Build>
A collection of build resources that match the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#builds ⇒ Array<Types::Build>
A collection of build resources that match the request.
7969 7970 7971 7972 7973 7974 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7969 class ListBuildsOutput < Struct.new( :builds, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
7969 7970 7971 7972 7973 7974 |
# File 'lib/aws-sdk-gamelift/types.rb', line 7969 class ListBuildsOutput < Struct.new( :builds, :next_token) SENSITIVE = [] include Aws::Structure end |