Class: Aws::GameLift::Types::ListContainerFleetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListContainerFleetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_fleets ⇒ Array<Types::ContainerFleet>
A collection of container fleet objects for all fleets that match the request criteria.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#container_fleets ⇒ Array<Types::ContainerFleet>
A collection of container fleet objects for all fleets that match the request criteria.
8764 8765 8766 8767 8768 8769 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8764 class ListContainerFleetsOutput < Struct.new( :container_fleets, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8764 8765 8766 8767 8768 8769 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8764 class ListContainerFleetsOutput < Struct.new( :container_fleets, :next_token) SENSITIVE = [] include Aws::Structure end |