Class: Aws::GameLift::Types::ListContainerGroupDefinitionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_group_typeString

The type of container group to retrieve. Container group type determines how Amazon GameLift Servers deploys the container group on each fleet instance.



8165
8166
8167
8168
8169
8170
8171
# File 'lib/aws-sdk-gamelift/types.rb', line 8165

class ListContainerGroupDefinitionsInput < Struct.new(
  :container_group_type,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.



8165
8166
8167
8168
8169
8170
8171
# File 'lib/aws-sdk-gamelift/types.rb', line 8165

class ListContainerGroupDefinitionsInput < Struct.new(
  :container_group_type,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value.



8165
8166
8167
8168
8169
8170
8171
# File 'lib/aws-sdk-gamelift/types.rb', line 8165

class ListContainerGroupDefinitionsInput < Struct.new(
  :container_group_type,
  :limit,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end