Class: Aws::GameLift::Types::ListContainerGroupDefinitionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::ListContainerGroupDefinitionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_group_definitions ⇒ Array<Types::ContainerGroupDefinition>
A result set of container group definitions that match the request.
-
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation.
Instance Attribute Details
#container_group_definitions ⇒ Array<Types::ContainerGroupDefinition>
A result set of container group definitions that match the request.
8446 8447 8448 8449 8450 8451 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8446 class ListContainerGroupDefinitionsOutput < Struct.new( :container_group_definitions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.
8446 8447 8448 8449 8450 8451 |
# File 'lib/aws-sdk-gamelift/types.rb', line 8446 class ListContainerGroupDefinitionsOutput < Struct.new( :container_group_definitions, :next_token) SENSITIVE = [] include Aws::Structure end |