Class: Aws::GameLift::Types::ListFleetsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fleet_idsArray<String>

A set of fleet IDs that match the list request.



8285
8286
8287
8288
8289
8290
# File 'lib/aws-sdk-gamelift/types.rb', line 8285

class ListFleetsOutput < Struct.new(
  :fleet_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates where to resume retrieving results on the next call to this operation. If no token is returned, these results represent the end of the list.



8285
8286
8287
8288
8289
8290
# File 'lib/aws-sdk-gamelift/types.rb', line 8285

class ListFleetsOutput < Struct.new(
  :fleet_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end