Class: Aws::GameLift::Types::MatchedPlayerSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::MatchedPlayerSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Represents a new player session that is created as a result of a successful FlexMatch match. A successful match automatically creates new player sessions for every player ID in the original matchmaking request.
When players connect to the match’s game session, they must include both player ID and player session ID in order to claim their assigned player slot.
Constant Summary collapse
- SENSITIVE =
[:player_id]
Instance Attribute Summary collapse
-
#player_id ⇒ String
A unique identifier for a player.
-
#player_session_id ⇒ String
A unique identifier for a player session.
Instance Attribute Details
#player_id ⇒ String
A unique identifier for a player
9458 9459 9460 9461 9462 9463 |
# File 'lib/aws-sdk-gamelift/types.rb', line 9458 class MatchedPlayerSession < Struct.new( :player_id, :player_session_id) SENSITIVE = [:player_id] include Aws::Structure end |
#player_session_id ⇒ String
A unique identifier for a player session. PlayerSessionId will only be populated for player sessions that are in ACTIVE or RESERVED status when the ticket is completed.
9458 9459 9460 9461 9462 9463 |
# File 'lib/aws-sdk-gamelift/types.rb', line 9458 class MatchedPlayerSession < Struct.new( :player_id, :player_session_id) SENSITIVE = [:player_id] include Aws::Structure end |