Class: Aws::GameLift::Types::PlayerConnectionEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::PlayerConnectionEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Network address(es) and port(s) for connecting to a game session.
Constant Summary collapse
- SENSITIVE =
[:ip_address, :port]
Instance Attribute Summary collapse
-
#ip_address ⇒ String
IP address for connecting to the game session.
-
#port ⇒ Integer
Port number for connecting to the game session.
Instance Attribute Details
#ip_address ⇒ String
IP address for connecting to the game session. When player gateway is enabled, this is a player gateway IP address. When player gateway is disabled, this is the game server IP address.
9671 9672 9673 9674 9675 9676 |
# File 'lib/aws-sdk-gamelift/types.rb', line 9671 class PlayerConnectionEndpoint < Struct.new( :ip_address, :port) SENSITIVE = [:ip_address, :port] include Aws::Structure end |
#port ⇒ Integer
Port number for connecting to the game session. When player gateway is enabled, this is a player gateway port. When player gateway is disabled, this is the game server port.
9671 9672 9673 9674 9675 9676 |
# File 'lib/aws-sdk-gamelift/types.rb', line 9671 class PlayerConnectionEndpoint < Struct.new( :ip_address, :port) SENSITIVE = [:ip_address, :port] include Aws::Structure end |