Class: Aws::GameLift::Types::PlayerGatewayConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::PlayerGatewayConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Configuration settings for player gateway. Use these settings to specify advanced options for how player gateway handles connections.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_server_ip_protocol_supported ⇒ String
The IP protocol that your game servers support for player connections through player gateway.
Instance Attribute Details
#game_server_ip_protocol_supported ⇒ String
The IP protocol that your game servers support for player connections through player gateway. If the value is set to ‘IPv4`, GameLift will install and execute a lightweight IP translation software on fleet instances to receive and transform incoming IPv6 traffic to IPv4. If the value is set to `DUAL_STACK`, the lightweight IP translation software will not be installed on fleet instances. `DUAL_STACK` provides slightly better performance than `IPv4`.
9721 9722 9723 9724 9725 |
# File 'lib/aws-sdk-gamelift/types.rb', line 9721 class PlayerGatewayConfiguration < Struct.new( :game_server_ip_protocol_supported) SENSITIVE = [] include Aws::Structure end |