Class: Aws::GameLift::Types::PlayerLatency
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::PlayerLatency
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Regional latency information for a player, used when requesting a new game session. This value indicates the amount of time lag that exists when the player is connected to a fleet in the specified location (an Amazon Web Services Region or a custom location for Amazon GameLift Servers Anywhere fleets). The relative difference between a player’s latency values for multiple locations are used to determine which fleets are best suited to place a new game session for the player.
Constant Summary collapse
- SENSITIVE =
[:player_id]
Instance Attribute Summary collapse
-
#latency_in_milliseconds ⇒ Float
Amount of time that represents the time lag experienced by the player when connected to the specified Region.
-
#player_id ⇒ String
A unique identifier for a player associated with the latency data.
-
#region_identifier ⇒ String
Name of the Region or custom location that is associated with the latency value.
Instance Attribute Details
#latency_in_milliseconds ⇒ Float
Amount of time that represents the time lag experienced by the player when connected to the specified Region.
10132 10133 10134 10135 10136 10137 10138 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10132 class PlayerLatency < Struct.new( :player_id, :region_identifier, :latency_in_milliseconds) SENSITIVE = [:player_id] include Aws::Structure end |
#player_id ⇒ String
A unique identifier for a player associated with the latency data.
10132 10133 10134 10135 10136 10137 10138 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10132 class PlayerLatency < Struct.new( :player_id, :region_identifier, :latency_in_milliseconds) SENSITIVE = [:player_id] include Aws::Structure end |
#region_identifier ⇒ String
Name of the Region or custom location that is associated with the latency value. For Amazon GameLift Servers Anywhere fleets, use the custom location name.
10132 10133 10134 10135 10136 10137 10138 |
# File 'lib/aws-sdk-gamelift/types.rb', line 10132 class PlayerLatency < Struct.new( :player_id, :region_identifier, :latency_in_milliseconds) SENSITIVE = [:player_id] include Aws::Structure end |