Class: Aws::GameLift::Types::ResourceCreationLimitPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

A policy that puts limits on the number of game sessions that a player can create within a specified span of time. With this policy, you can control players’ ability to consume available resources.

The policy is evaluated when a player tries to create a new game session. On receiving a ‘CreateGameSession` request, Amazon GameLift Servers checks that the player (identified by `CreatorId`) has created fewer than game session limit in the specified time period.

The purpose of this policy is to prevent a single player from consuming a large share of available hosting resources. For example, setting ‘NewGameSessionsPerCreator` to `4` and `PolicyPeriodInMinutes` to `10` limits each player to creating 4 game sessions every 10 minutes. Setting these values too high (for example, 200 game sessions every 1000 minutes) still allows a single player to rapidly consume resources. We recommend keeping these values small.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#new_game_sessions_per_creatorInteger

A policy that puts limits on the number of game sessions that a player can create within a specified span of time. With this policy, you can control players’ ability to consume available resources.

The policy is evaluated when a player tries to create a new game session. On receiving a ‘CreateGameSession` request, Amazon GameLift Servers checks that the player (identified by `CreatorId`) has created fewer than game session limit in the specified time period.

Returns:

  • (Integer)


10773
10774
10775
10776
10777
10778
# File 'lib/aws-sdk-gamelift/types.rb', line 10773

class ResourceCreationLimitPolicy < Struct.new(
  :new_game_sessions_per_creator,
  :policy_period_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#policy_period_in_minutesInteger

The time span used in evaluating the resource creation limit policy.

Returns:

  • (Integer)


10773
10774
10775
10776
10777
10778
# File 'lib/aws-sdk-gamelift/types.rb', line 10773

class ResourceCreationLimitPolicy < Struct.new(
  :new_game_sessions_per_creator,
  :policy_period_in_minutes)
  SENSITIVE = []
  include Aws::Structure
end