Class: Aws::GameLift::Types::StartMatchBackfillInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_nameString

Name of the matchmaker to use for this request. You can use either the configuration name or ARN value. The ARN of the matchmaker that was used with the original game session is listed in the ‘GameSession` object, `MatchmakerData` property.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
# File 'lib/aws-sdk-gamelift/types.rb', line 11434

class StartMatchBackfillInput < Struct.new(
  :ticket_id,
  :configuration_name,
  :game_session_arn,
  :players)
  SENSITIVE = []
  include Aws::Structure
end

#game_session_arnString

An identifier for the game session that is unique across all regions. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`. When using FlexMatch as a standalone matchmaking solution, this parameter is not needed.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
# File 'lib/aws-sdk-gamelift/types.rb', line 11434

class StartMatchBackfillInput < Struct.new(
  :ticket_id,
  :configuration_name,
  :game_session_arn,
  :players)
  SENSITIVE = []
  include Aws::Structure
end

#playersArray<Types::Player>

Match information on all players that are currently assigned to the game session. This information is used by the matchmaker to find new players and add them to the existing game.

You can include up to 199 ‘Players` in a `StartMatchBackfill` request.

  • PlayerID, PlayerAttributes, Team – This information is maintained in the ‘GameSession` object, `MatchmakerData` property, for all players who are currently assigned to the game session. The matchmaker data is in JSON syntax, formatted as a string. For more details, see [ Match Data].

    The backfill request must specify the team membership for every player. Do not specify team if you are not using backfill.

  • LatencyInMs – If the matchmaker uses player latency, include a latency value, in milliseconds, for the Region that the game session is currently in. Do not include latency values for any other Region.

[1]: docs.aws.amazon.com/gamelift/latest/flexmatchguide/match-server.html#match-server-data

Returns:



11434
11435
11436
11437
11438
11439
11440
11441
# File 'lib/aws-sdk-gamelift/types.rb', line 11434

class StartMatchBackfillInput < Struct.new(
  :ticket_id,
  :configuration_name,
  :game_session_arn,
  :players)
  SENSITIVE = []
  include Aws::Structure
end

#ticket_idString

A unique identifier for a matchmaking ticket. If no ticket ID is specified here, Amazon GameLift Servers will generate one in the form of a UUID. Use this identifier to track the match backfill ticket status and retrieve match results.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
# File 'lib/aws-sdk-gamelift/types.rb', line 11434

class StartMatchBackfillInput < Struct.new(
  :ticket_id,
  :configuration_name,
  :game_session_arn,
  :players)
  SENSITIVE = []
  include Aws::Structure
end