Class: Aws::GameLift::Types::StartMatchBackfillOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matchmaking_ticketTypes::MatchmakingTicket

Ticket representing the backfill matchmaking request. This object includes the information in the request, ticket status, and match results as generated during the matchmaking process.



11626
11627
11628
11629
11630
# File 'lib/aws-sdk-gamelift/types.rb', line 11626

class StartMatchBackfillOutput < Struct.new(
  :matchmaking_ticket)
  SENSITIVE = []
  include Aws::Structure
end