Class: Aws::GameLift::Types::StartMatchBackfillOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::StartMatchBackfillOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the backfill matchmaking request.
Instance Attribute Details
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the backfill matchmaking request. This object includes the information in the request, ticket status, and match results as generated during the matchmaking process.
11179 11180 11181 11182 11183 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11179 class StartMatchBackfillOutput < Struct.new( :matchmaking_ticket) SENSITIVE = [] include Aws::Structure end |