Class: Aws::GameLift::Types::StartMatchmakingOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::StartMatchmakingOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the matchmaking request.
Instance Attribute Details
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the matchmaking request. This object include the information included in the request, ticket status, and match results as generated during the matchmaking process.
11673 11674 11675 11676 11677 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11673 class StartMatchmakingOutput < Struct.new( :matchmaking_ticket) SENSITIVE = [] include Aws::Structure end |