Class: Aws::GameLift::Types::StartMatchmakingOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::StartMatchmakingOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the matchmaking request.
Instance Attribute Details
#matchmaking_ticket ⇒ Types::MatchmakingTicket
Ticket representing the matchmaking request. This object include the information included in the request, ticket status, and match results as generated during the matchmaking process.
11661 11662 11663 11664 11665 |
# File 'lib/aws-sdk-gamelift/types.rb', line 11661 class StartMatchmakingOutput < Struct.new( :matchmaking_ticket) SENSITIVE = [] include Aws::Structure end |