Class: Aws::GameLift::Types::StartMatchmakingOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matchmaking_ticketTypes::MatchmakingTicket

Ticket representing the matchmaking request. This object include the information included in the request, ticket status, and match results as generated during the matchmaking process.



11221
11222
11223
11224
11225
# File 'lib/aws-sdk-gamelift/types.rb', line 11221

class StartMatchmakingOutput < Struct.new(
  :matchmaking_ticket)
  SENSITIVE = []
  include Aws::Structure
end