Class: Aws::GameLift::Types::TerminateGameSessionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::TerminateGameSessionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_session ⇒ Types::GameSession
Properties describing a game session.
Instance Attribute Details
#game_session ⇒ Types::GameSession
Properties describing a game session.
A game session in ACTIVE status can host players. When a game
session ends, its status is set to TERMINATED.
Amazon GameLift Servers retains a game session resource for 30 days after the game session ends. You can reuse idempotency token values after this time. Game session logs are retained for 14 days.
12327 12328 12329 12330 12331 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12327 class TerminateGameSessionOutput < Struct.new( :game_session) SENSITIVE = [] include Aws::Structure end |