Class: Aws::GameLift::Types::UpdateFleetCapacityInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#desired_instancesInteger

The number of Amazon EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits. Changes in desired instance value can take up to 1 minute to be reflected when viewing the fleet’s capacity settings.

Returns:

  • (Integer)


12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

A unique identifier for the fleet to update capacity settings for. You can use either the fleet ID or ARN value.

Returns:

  • (String)


12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The name of a remote location to update fleet capacity settings for, in the form of an Amazon Web Services Region code such as ‘us-west-2`.

Returns:

  • (String)


12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#managed_capacity_configurationTypes::ManagedCapacityConfiguration

Configuration for Amazon GameLift Servers-managed capacity scaling options.



12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#max_sizeInteger

The maximum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 1.

Returns:

  • (Integer)


12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#min_sizeInteger

The minimum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 0. This parameter cannot be set when using a ManagedCapacityConfiguration where ZeroCapacityStrategy has a value of SCALE_TO_AND_FROM_ZERO.

Returns:

  • (Integer)


12844
12845
12846
12847
12848
12849
12850
12851
12852
12853
# File 'lib/aws-sdk-gamelift/types.rb', line 12844

class UpdateFleetCapacityInput < Struct.new(
  :fleet_id,
  :desired_instances,
  :min_size,
  :max_size,
  :location,
  :managed_capacity_configuration)
  SENSITIVE = []
  include Aws::Structure
end