Class: Aws::GameLift::Types::UpdateFleetCapacityInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateFleetCapacityInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#desired_instances ⇒ Integer
The number of Amazon EC2 instances you want to maintain in the specified fleet location.
-
#fleet_id ⇒ String
A unique identifier for the fleet to update capacity settings for.
-
#location ⇒ String
The name of a remote location to update fleet capacity settings for, in the form of an Amazon Web Services Region code such as
us-west-2. -
#managed_capacity_configuration ⇒ Types::ManagedCapacityConfiguration
Configuration for Amazon GameLift Servers-managed capacity scaling options.
-
#max_size ⇒ Integer
The maximum number of instances that are allowed in the specified fleet location.
-
#min_size ⇒ Integer
The minimum number of instances that are allowed in the specified fleet location.
Instance Attribute Details
#desired_instances ⇒ Integer
The number of Amazon EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits. Changes in desired instance value can take up to 1 minute to be reflected when viewing the fleet’s capacity settings.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
A unique identifier for the fleet to update capacity settings for. You can use either the fleet ID or ARN value.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The name of a remote location to update fleet capacity settings for, in the form of an Amazon Web Services Region code such as us-west-2.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |
#managed_capacity_configuration ⇒ Types::ManagedCapacityConfiguration
Configuration for Amazon GameLift Servers-managed capacity scaling options.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |
#max_size ⇒ Integer
The maximum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 1.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |
#min_size ⇒ Integer
The minimum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 0. This parameter cannot be set when using a ManagedCapacityConfiguration where ZeroCapacityStrategy has a value of SCALE_TO_AND_FROM_ZERO.
12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12366 class UpdateFleetCapacityInput < Struct.new( :fleet_id, :desired_instances, :min_size, :max_size, :location, :managed_capacity_configuration) SENSITIVE = [] include Aws::Structure end |