Class: Aws::GameLift::Types::UpdateGameSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateGameSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session.
-
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to update.
-
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
-
#name ⇒ String
A descriptive label that is associated with a game session.
-
#player_session_creation_policy ⇒ String
A policy that determines whether the game session is accepting new players.
-
#protection_policy ⇒ String
Game session protection policy to apply to this game session only.
Instance Attribute Details
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session. For example: ‘“difficulty”, “Value”: “novice”`. You can use this parameter to modify game properties in an active game session. This action adds new properties and modifies existing properties. There is no way to delete properties. For an example, see [Update the value of a game property].
<note markdown=“1”> * Avoid using periods (“.”) in property keys if you plan to search
for game sessions by properties. Property keys containing periods
cannot be searched and will be filtered out from search results
due to search index limitations.
-
If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.
</note>
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#game_session_id ⇒ String
An identifier for the game session that is unique across all regions to update. The value is always a full ARN in the following format: ‘arn:aws:gamelift:<location>::gamesession/<fleet ID>/<ID string>`.
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive label that is associated with a game session. Session names do not need to be unique.
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#player_session_creation_policy ⇒ String
A policy that determines whether the game session is accepting new players.
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#protection_policy ⇒ String
Game session protection policy to apply to this game session only.
-
‘NoProtection` – The game session can be terminated during a scale-down event.
-
‘FullProtection` – If the game session is in an `ACTIVE` status, it cannot be terminated during a scale-down event.
12952 12953 12954 12955 12956 12957 12958 12959 12960 12961 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12952 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |