Class: Aws::GameLift::Types::UpdateGameSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateGameSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session.
-
#game_session_id ⇒ String
A unique identifier for the game session to update.
-
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
-
#name ⇒ String
A descriptive label that is associated with a game session.
-
#player_session_creation_policy ⇒ String
A policy that determines whether the game session is accepting new players.
-
#protection_policy ⇒ String
Game session protection policy to apply to this game session only.
Instance Attribute Details
#game_properties ⇒ Array<Types::GameProperty>
A set of key-value pairs that can store custom data in a game session. For example: ‘“difficulty”, “Value”: “novice”`. You can use this parameter to modify game properties in an active game session. This action adds new properties and modifies existing properties. There is no way to delete properties. For an example, see [Update the value of a game property].
<note markdown=“1”> * Avoid using periods (“.”) in property keys if you plan to search
for game sessions by properties. Property keys containing periods
cannot be searched and will be filtered out from search results
due to search index limitations.
-
If you use SearchGameSessions API, there is a limit of 500 game property keys across all game sessions and all fleets per region. If the limit is exceeded, there will potentially be game session entries missing from SearchGameSessions API results.
</note>
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#game_session_id ⇒ String
A unique identifier for the game session to update.
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#maximum_player_session_count ⇒ Integer
The maximum number of players that can be connected simultaneously to the game session.
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive label that is associated with a game session. Session names do not need to be unique.
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#player_session_creation_policy ⇒ String
A policy that determines whether the game session is accepting new players.
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |
#protection_policy ⇒ String
Game session protection policy to apply to this game session only.
-
NoProtection– The game session can be terminated during a scale-down event. -
FullProtection– If the game session is in anACTIVEstatus, it cannot be terminated during a scale-down event.
12664 12665 12666 12667 12668 12669 12670 12671 12672 12673 |
# File 'lib/aws-sdk-gamelift/types.rb', line 12664 class UpdateGameSessionInput < Struct.new( :game_session_id, :maximum_player_session_count, :name, :player_session_creation_policy, :protection_policy, :game_properties) SENSITIVE = [] include Aws::Structure end |