Class: Aws::GameLift::Types::UpdateGameSessionQueueInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gamelift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_event_dataString

Information to be added to all events that are related to this game session queue.

Returns:

  • (String)


13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::GameSessionQueueDestination>

A list of fleets and/or fleet aliases that can be used to fulfill game session placement requests in the queue. Destinations are identified by either a fleet ARN or a fleet alias ARN, and are listed in order of placement preference. When updating this list, provide a complete list of destinations.



13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#filter_configurationTypes::FilterConfiguration

A list of locations where a queue is allowed to place new game sessions. Locations are specified in the form of Amazon Web Services Region codes, such as ‘us-west-2`. If this parameter is not set, game sessions can be placed in any queue location. To remove an existing filter configuration, pass in an empty set.



13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive label that is associated with game session queue. Queue names must be unique within each Region. You can use either the queue ID or ARN value.

Returns:

  • (String)


13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#notification_targetString

An SNS topic ARN that is set up to receive game session placement notifications. See [ Setting up notifications for game session placement].

[1]: docs.aws.amazon.com/gamelift/latest/developerguide/queue-notification.html

Returns:

  • (String)


13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#player_latency_policiesArray<Types::PlayerLatencyPolicy>

A set of policies that enforce a sliding cap on player latency when processing game sessions placement requests. Use multiple policies to gradually relax the cap over time if Amazon GameLift Servers can’t make a placement. Policies are evaluated in order starting with the lowest maximum latency value. When updating policies, provide a complete collection of policies.

Returns:



13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#priority_configurationTypes::PriorityConfiguration

Custom settings to use when prioritizing destinations and locations for game session placements. This configuration replaces the FleetIQ default prioritization process. Priority types that are not explicitly named will be automatically applied at the end of the prioritization process. To remove an existing priority configuration, pass in an empty set.



13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_in_secondsInteger

The maximum time, in seconds, that a new game session placement request remains in the queue. When a request exceeds this time, the game session placement changes to a ‘TIMED_OUT` status.

<note markdown=“1”> The minimum value is 10 and the maximum value is 600.

</note>

Returns:

  • (Integer)


13042
13043
13044
13045
13046
13047
13048
13049
13050
13051
13052
13053
# File 'lib/aws-sdk-gamelift/types.rb', line 13042

class UpdateGameSessionQueueInput < Struct.new(
  :name,
  :timeout_in_seconds,
  :player_latency_policies,
  :destinations,
  :filter_configuration,
  :priority_configuration,
  :custom_event_data,
  :notification_target)
  SENSITIVE = []
  include Aws::Structure
end