Class: Aws::GameLift::Types::UpdateRuntimeConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLift::Types::UpdateRuntimeConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gamelift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_id ⇒ String
A unique identifier for the fleet to update runtime configuration for.
-
#runtime_configuration ⇒ Types::RuntimeConfiguration
Instructions for launching server processes on fleet computes.
Instance Attribute Details
#fleet_id ⇒ String
A unique identifier for the fleet to update runtime configuration for. You can use either the fleet ID or ARN value.
13462 13463 13464 13465 13466 13467 |
# File 'lib/aws-sdk-gamelift/types.rb', line 13462 class UpdateRuntimeConfigurationInput < Struct.new( :fleet_id, :runtime_configuration) SENSITIVE = [] include Aws::Structure end |
#runtime_configuration ⇒ Types::RuntimeConfiguration
Instructions for launching server processes on fleet computes. Server processes run either a custom game build executable or a Amazon GameLift Servers Realtime script. The runtime configuration lists the types of server processes to run, how to launch them, and the number of processes to run concurrently.
13462 13463 13464 13465 13466 13467 |
# File 'lib/aws-sdk-gamelift/types.rb', line 13462 class UpdateRuntimeConfigurationInput < Struct.new( :fleet_id, :runtime_configuration) SENSITIVE = [] include Aws::Structure end |